@@ -6,6 +6,10 @@ pub use date::*;
 mod datetime;
 #[cfg(feature = "dtype-datetime")]
 pub use datetime::*;
+#[cfg(feature = "dtype-i128")]
+mod decimal;
+#[cfg(feature = "dtype-i128")]
+pub use decimal::*;
 #[cfg(feature = "dtype-duration")]
 mod duration;
 #[cfg(feature = "dtype-duration")]
