@@ -61,7 +61,7 @@ where
                 .collect::<PrimitiveArray<T::Native>>()
                 .to(T::get_dtype().to_arrow()),
         };
-        ChunkedArray::from_chunks("", vec![Box::new(arr)])
+        unsafe { ChunkedArray::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -82,7 +82,7 @@ where
 impl FromIterator<Option<bool>> for ChunkedArray<BooleanType> {
     fn from_iter<I: IntoIterator<Item = Option<bool>>>(iter: I) -> Self {
         let arr = BooleanArray::from_iter(iter);
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -90,7 +90,7 @@ impl FromIterator<bool> for BooleanChunked {
     fn from_iter<I: IntoIterator<Item = bool>>(iter: I) -> Self {
         // 2021-02-07: this was ~70% faster than with the builder, even with the extra Option<T> added.
         let arr = BooleanArray::from_iter(iter.into_iter().map(Some));
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -109,7 +109,7 @@ where
 {
     fn from_iter<I: IntoIterator<Item = Option<Ptr>>>(iter: I) -> Self {
         let arr = Utf8Array::<i64>::from_iter(iter);
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -128,7 +128,7 @@ where
 {
     fn from_iter<I: IntoIterator<Item = Ptr>>(iter: I) -> Self {
         let arr = Utf8Array::<i64>::from_iter_values(iter.into_iter());
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -140,7 +140,7 @@ where
 {
     fn from_iter<I: IntoIterator<Item = Option<Ptr>>>(iter: I) -> Self {
         let arr = BinaryArray::<i64>::from_iter(iter);
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -163,7 +163,7 @@ where
 {
     fn from_iter<I: IntoIterator<Item = Ptr>>(iter: I) -> Self {
         let arr = BinaryArray::<i64>::from_iter_values(iter.into_iter());
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -397,7 +397,7 @@ where
             av.extend_from_slice(&v)
         }
         let arr = to_array::<T>(av, None);
-        NoNull::new(ChunkedArray::from_chunks("", vec![arr]))
+        unsafe { NoNull::new(ChunkedArray::from_chunks("", vec![arr])) }
     }
 }
 
@@ -414,7 +414,7 @@ where
         let iter = TrustMyLength::new(vectors.into_iter().flatten(), capacity);
         let arr =
             PrimitiveArray::<T::Native>::from_trusted_len_iter(iter).to(T::get_dtype().to_arrow());
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -429,7 +429,7 @@ impl FromParallelIterator<bool> for BooleanChunked {
                 vectors.into_iter().flatten().trust_my_length(capacity),
             )
         };
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -444,7 +444,7 @@ impl FromParallelIterator<Option<bool>> for BooleanChunked {
                 vectors.into_iter().flatten().trust_my_length(capacity),
             )
         };
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -455,7 +455,7 @@ where
     fn from_par_iter<I: IntoParallelIterator<Item = Ptr>>(iter: I) -> Self {
         let vectors = collect_into_linked_list(iter);
         let arr = LargeStringArray::from_iter_values(vectors.into_iter().flatten());
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
@@ -466,7 +466,7 @@ where
     fn from_par_iter<I: IntoParallelIterator<Item = Option<Ptr>>>(iter: I) -> Self {
         let vectors = collect_into_linked_list(iter);
         let arr = LargeStringArray::from_iter(vectors.into_iter().flatten());
-        Self::from_chunks("", vec![Box::new(arr)])
+        unsafe { Self::from_chunks("", vec![Box::new(arr)]) }
     }
 }
 
