@@ -374,7 +374,6 @@ impl<'a> AnyValue<'a> {
     pub fn extract<T: NumCast>(&self) -> Option<T> {
         use AnyValue::*;
         match self {
-            Null => None,
             Int8(v) => NumCast::from(*v),
             Int16(v) => NumCast::from(*v),
             Int32(v) => NumCast::from(*v),
@@ -400,7 +399,7 @@ impl<'a> AnyValue<'a> {
                     NumCast::from(0)
                 }
             }
-            dt => panic!("dtype {dt:?} not implemented"),
+            _ => None,
         }
     }
 
@@ -569,6 +568,24 @@ impl<'a> AnyValue<'a> {
         };
         Ok(av)
     }
+
+    /// Get a reference to the `&str` contained within [`AnyValue`].
+    pub fn get_str(&self) -> Option<&str> {
+        match self {
+            AnyValue::Utf8(s) => Some(s),
+            AnyValue::Utf8Owned(s) => Some(s),
+            #[cfg(feature = "dtype-categorical")]
+            AnyValue::Categorical(idx, rev, arr) => {
+                let s = if arr.is_null() {
+                    rev.get(*idx)
+                } else {
+                    unsafe { arr.deref_unchecked().value(*idx as usize) }
+                };
+                Some(s)
+            }
+            _ => None,
+        }
+    }
 }
 
 impl<'a> From<AnyValue<'a>> for Option<i64> {
