@@ -22,7 +22,6 @@ use std::ops::{Add, AddAssign, Div, Mul, Rem, Sub, SubAssign};
 use ahash::RandomState;
 pub use aliases::*;
 pub use any_value::*;
-use arrow::compute::arithmetics::basic::NativeArithmetics;
 use arrow::compute::comparison::Simd8;
 #[cfg(feature = "dtype-categorical")]
 use arrow::datatypes::IntegerType;
@@ -41,6 +40,7 @@ use serde::{Deserialize, Serialize};
 use serde::{Deserializer, Serializer};
 pub use time_unit::*;
 
+use crate::chunked_array::arithmetic::ArrayArithmetics;
 pub use crate::chunked_array::logical::*;
 #[cfg(feature = "object")]
 use crate::chunked_array::object::PolarsObjectSafe;
@@ -85,6 +85,8 @@ impl_polars_datatype!(Int64Type, Int64, i64);
 impl_polars_datatype!(Float32Type, Float32, f32);
 impl_polars_datatype!(Float64Type, Float64, f64);
 impl_polars_datatype!(DateType, Date, i32);
+#[cfg(feature = "dtype-i128")]
+impl_polars_datatype!(DecimalType, Unknown, i128);
 impl_polars_datatype!(DatetimeType, Unknown, i64);
 impl_polars_datatype!(DurationType, Unknown, i64);
 impl_polars_datatype!(CategoricalType, Unknown, u32);
@@ -118,14 +120,23 @@ impl PolarsDataType for ListType {
     }
 }
 
+#[cfg(feature = "dtype-i128")]
+pub struct Int128Type {}
+
+#[cfg(feature = "dtype-i128")]
+impl PolarsDataType for Int128Type {
+    fn get_dtype() -> DataType {
+        // we cannot know precision/scale statically
+        DataType::Decimal128(None)
+    }
+}
+
 #[cfg(feature = "object")]
-#[cfg_attr(docsrs, doc(cfg(feature = "object")))]
 pub struct ObjectType<T>(T);
 #[cfg(feature = "object")]
 pub type ObjectChunked<T> = ChunkedArray<ObjectType<T>>;
 
 #[cfg(feature = "object")]
-#[cfg_attr(docsrs, doc(cfg(feature = "object")))]
 impl<T: PolarsObject> PolarsDataType for ObjectType<T> {
     fn get_dtype() -> DataType {
         DataType::Object(T::type_name())
@@ -152,6 +163,8 @@ pub type Int8Chunked = ChunkedArray<Int8Type>;
 pub type Int16Chunked = ChunkedArray<Int16Type>;
 pub type Int32Chunked = ChunkedArray<Int32Type>;
 pub type Int64Chunked = ChunkedArray<Int64Type>;
+#[cfg(feature = "dtype-i128")]
+pub type Int128Chunked = ChunkedArray<Int128Type>;
 pub type Float32Chunked = ChunkedArray<Float32Type>;
 pub type Float64Chunked = ChunkedArray<Float64Type>;
 pub type Utf8Chunked = ChunkedArray<Utf8Type>;
@@ -177,7 +190,7 @@ pub trait NumericNative:
     + Bounded
     + FromPrimitive
     + IsFloat
-    + NativeArithmetics
+    + ArrayArithmetics
 {
     type POLARSTYPE: PolarsNumericType;
 }
@@ -206,6 +219,10 @@ impl NumericNative for u32 {
 impl NumericNative for u64 {
     type POLARSTYPE = UInt64Type;
 }
+#[cfg(feature = "dtype-i128")]
+impl NumericNative for i128 {
+    type POLARSTYPE = Int128Type;
+}
 impl NumericNative for f32 {
     type POLARSTYPE = Float32Type;
 }
@@ -240,6 +257,10 @@ impl PolarsNumericType for Int32Type {
 impl PolarsNumericType for Int64Type {
     type Native = i64;
 }
+#[cfg(feature = "dtype-i128")]
+impl PolarsNumericType for Int128Type {
+    type Native = i128;
+}
 impl PolarsNumericType for Float32Type {
     type Native = f32;
 }
