@@ -22,6 +22,8 @@ macro_rules! impl_compare {
         match lhs.dtype() {
             DataType::Boolean => lhs.bool().unwrap().$method(rhs.bool().unwrap()),
             DataType::Utf8 => lhs.utf8().unwrap().$method(rhs.utf8().unwrap()),
+            #[cfg(feature = "dtype-binary")]
+            DataType::Binary => lhs.binary().unwrap().$method(rhs.binary().unwrap()),
             DataType::UInt8 => lhs.u8().unwrap().$method(rhs.u8().unwrap()),
             DataType::UInt16 => lhs.u16().unwrap().$method(rhs.u16().unwrap()),
             DataType::UInt32 => lhs.u32().unwrap().$method(rhs.u32().unwrap()),
@@ -127,54 +129,9 @@ fn validate_types(left: &DataType, right: &DataType) -> PolarsResult<()> {
 impl ChunkCompare<&Series> for Series {
     type Item = PolarsResult<BooleanChunked>;
 
-    fn eq_missing(&self, rhs: &Series) -> PolarsResult<BooleanChunked> {
-        validate_types(self.dtype(), rhs.dtype())?;
-        #[cfg(feature = "dtype-categorical")]
-        use DataType::*;
-        let mut out = match (self.dtype(), rhs.dtype(), self.len(), rhs.len()) {
-            #[cfg(feature = "dtype-categorical")]
-            (Categorical(_), Utf8, _, 1) => {
-                return compare_cat_to_str_series(
-                    self,
-                    rhs,
-                    self.name(),
-                    |s, idx| s.eq_missing(idx),
-                    false,
-                );
-            }
-            #[cfg(feature = "dtype-categorical")]
-            (Utf8, Categorical(_), 1, _) => {
-                return compare_cat_to_str_series(
-                    rhs,
-                    self,
-                    self.name(),
-                    |s, idx| s.eq_missing(idx),
-                    false,
-                );
-            }
-            #[cfg(feature = "dtype-categorical")]
-            (Categorical(Some(rev_map_l)), Categorical(Some(rev_map_r)), _, _) => {
-                if rev_map_l.same_src(rev_map_r) {
-                    self.categorical()
-                        .unwrap()
-                        .logical()
-                        .eq_missing(rhs.categorical().unwrap().logical())
-                } else {
-                    return Err(PolarsError::ComputeError("Cannot compare categoricals originating from different sources. Consider setting a global string cache.".into()));
-                }
-            }
-            _ => {
-                impl_compare!(self, rhs, eq_missing)
-            }
-        };
-        out.rename(self.name());
-        Ok(out)
-    }
-
     /// Create a boolean mask by checking for equality.
     fn equal(&self, rhs: &Series) -> PolarsResult<BooleanChunked> {
         validate_types(self.dtype(), rhs.dtype())?;
-        #[cfg(feature = "dtype-categorical")]
         use DataType::*;
         let mut out = match (self.dtype(), rhs.dtype(), self.len(), rhs.len()) {
             #[cfg(feature = "dtype-categorical")]
@@ -200,14 +157,22 @@ impl ChunkCompare<&Series> for Series {
             #[cfg(feature = "dtype-categorical")]
             (Categorical(Some(rev_map_l)), Categorical(Some(rev_map_r)), _, _) => {
                 if rev_map_l.same_src(rev_map_r) {
-                    self.categorical()
-                        .unwrap()
-                        .logical()
-                        .equal(rhs.categorical().unwrap().logical())
+                    let rhs = rhs.categorical().unwrap().logical();
+
+                    // first check the rev-map
+                    if rhs.len() == 1 && rhs.null_count() == 0 {
+                        let rhs = rhs.get(0).unwrap();
+                        if rev_map_l.get_optional(rhs).is_none() {
+                            return Ok(BooleanChunked::full(self.name(), false, self.len()));
+                        }
+                    }
+
+                    self.categorical().unwrap().logical().equal(rhs)
                 } else {
                     return Err(PolarsError::ComputeError("Cannot compare categoricals originating from different sources. Consider setting a global string cache.".into()));
                 }
             }
+            (Null, Null, _, _) => BooleanChunked::full(self.name(), true, self.len()),
             _ => {
                 impl_compare!(self, rhs, equal)
             }
@@ -219,7 +184,6 @@ impl ChunkCompare<&Series> for Series {
     /// Create a boolean mask by checking for inequality.
     fn not_equal(&self, rhs: &Series) -> PolarsResult<BooleanChunked> {
         validate_types(self.dtype(), rhs.dtype())?;
-        #[cfg(feature = "dtype-categorical")]
         use DataType::*;
         let mut out = match (self.dtype(), rhs.dtype(), self.len(), rhs.len()) {
             #[cfg(feature = "dtype-categorical")]
@@ -245,14 +209,22 @@ impl ChunkCompare<&Series> for Series {
             #[cfg(feature = "dtype-categorical")]
             (Categorical(Some(rev_map_l)), Categorical(Some(rev_map_r)), _, _) => {
                 if rev_map_l.same_src(rev_map_r) {
-                    self.categorical()
-                        .unwrap()
-                        .logical()
-                        .not_equal(rhs.categorical().unwrap().logical())
+                    let rhs = rhs.categorical().unwrap().logical();
+
+                    // first check the rev-map
+                    if rhs.len() == 1 && rhs.null_count() == 0 {
+                        let rhs = rhs.get(0).unwrap();
+                        if rev_map_l.get_optional(rhs).is_none() {
+                            return Ok(BooleanChunked::full(self.name(), true, self.len()));
+                        }
+                    }
+
+                    self.categorical().unwrap().logical().not_equal(rhs)
                 } else {
                     return Err(PolarsError::ComputeError("Cannot compare categoricals originating from different sources. Consider setting a global string cache.".into()));
                 }
             }
+            (Null, Null, _, _) => BooleanChunked::full(self.name(), false, self.len()),
             _ => {
                 impl_compare!(self, rhs, not_equal)
             }
@@ -300,12 +272,6 @@ where
 {
     type Item = PolarsResult<BooleanChunked>;
 
-    fn eq_missing(&self, rhs: Rhs) -> PolarsResult<BooleanChunked> {
-        // just take any numeric dtype for rhs
-        validate_types(self.dtype(), &DataType::Int8)?;
-        self.equal(rhs)
-    }
-
     fn equal(&self, rhs: Rhs) -> PolarsResult<BooleanChunked> {
         validate_types(self.dtype(), &DataType::Int8)?;
         let s = self.to_physical_repr();
@@ -345,11 +311,6 @@ where
 
 impl ChunkCompare<&str> for Series {
     type Item = PolarsResult<BooleanChunked>;
-    fn eq_missing(&self, rhs: &str) -> PolarsResult<BooleanChunked> {
-        validate_types(self.dtype(), &DataType::Utf8)?;
-        self.equal(rhs)
-    }
-
     fn equal(&self, rhs: &str) -> PolarsResult<BooleanChunked> {
         validate_types(self.dtype(), &DataType::Utf8)?;
         use DataType::*;
