@@ -16,6 +16,7 @@ use crate::chunked_array::cast::cast_chunks;
 use crate::chunked_array::object::extension::polars_extension::PolarsExtension;
 #[cfg(feature = "object")]
 use crate::chunked_array::object::extension::EXTENSION_NAME;
+use crate::config::verbose;
 use crate::prelude::*;
 
 impl Series {
@@ -87,7 +88,7 @@ impl Series {
             Struct(_) => Series::try_from_arrow_unchecked(name, chunks, &dtype.to_arrow()).unwrap(),
             #[cfg(feature = "object")]
             Object(_) => todo!(),
-            Null => panic!("null type not supported"),
+            Null => new_null(name, &chunks),
             Unknown => panic!("uh oh, somehow we don't know the dtype?"),
             #[allow(unreachable_patterns)]
             _ => unreachable!(),
@@ -225,14 +226,7 @@ impl Series {
                     ArrowTimeUnit::Nanosecond => s,
                 })
             }
-            ArrowDataType::Null => {
-                // we don't support null types yet so we use a small digit type filled with nulls
-                let len = chunks.iter().fold(0, |acc, array| acc + array.len());
-                #[cfg(feature = "dtype-i8")]
-                return Ok(Int8Chunked::full_null(name, len).into_series());
-                #[cfg(not(feature = "dtype-i8"))]
-                Ok(UInt32Chunked::full_null(name, len).into_series())
-            }
+            ArrowDataType::Null => Ok(new_null(name, &chunks)),
             #[cfg(not(feature = "dtype-categorical"))]
             ArrowDataType::Dictionary(_, _, _) => {
                 panic!("activate dtype-categorical to convert dictionary arrays")
@@ -369,10 +363,28 @@ impl Series {
                     .collect::<PolarsResult<Vec<_>>>()?;
                 Ok(StructChunked::new_unchecked(name, &fields).into_series())
             }
+            ArrowDataType::FixedSizeBinary(_) => {
+                #[cfg(feature = "dtype-binary")]
+                {
+                    if verbose() {
+                        eprintln!(
+                            "Polars does not support decimal types so the 'Series' are read as Float64"
+                        );
+                    }
+                    let chunks = cast_chunks(&chunks, &DataType::Binary, true)?;
+                    Ok(BinaryChunked::from_chunks(name, chunks).into_series())
+                }
+                #[cfg(not(feature = "dtype-binary"))]
+                {
+                    panic!("activate 'dtype-binary' feature")
+                }
+            }
             ArrowDataType::Decimal(_, _) | ArrowDataType::Decimal256(_, _) => {
-                eprintln!(
-                    "Polars does not support decimal types so the 'Series' are read as Float64"
-                );
+                if verbose() {
+                    eprintln!(
+                        "Polars does not support decimal types so the 'Series' are read as Float64"
+                    );
+                }
                 Ok(Float64Chunked::from_chunks(
                     name,
                     cast_chunks(&chunks, &DataType::Float64, true)?,
@@ -418,6 +430,11 @@ fn convert_inner_types(arr: &ArrayRef) -> ArrayRef {
             let out = cast(&**arr, &ArrowDataType::LargeList(field.clone())).unwrap();
             convert_inner_types(&out)
         }
+        #[cfg(feature = "dtype-binary")]
+        ArrowDataType::FixedSizeBinary(_) | ArrowDataType::Binary => {
+            let out = cast(&**arr, &ArrowDataType::LargeBinary).unwrap();
+            convert_inner_types(&out)
+        }
         ArrowDataType::LargeList(_) => {
             let arr = arr.as_any().downcast_ref::<ListArray<i64>>().unwrap();
             let values = convert_inner_types(arr.values());
@@ -559,6 +576,11 @@ unsafe impl IntoSeries for Series {
     }
 }
 
+fn new_null(name: &str, chunks: &[ArrayRef]) -> Series {
+    let len = chunks.iter().map(|arr| arr.len()).sum();
+    Series::new_null(name, len)
+}
+
 #[cfg(test)]
 mod test {
     #[cfg(all(feature = "dtype-u8", not(feature = "dtype-binary")))]
