@@ -100,8 +100,8 @@ impl private::PrivateSeries for SeriesWrap<BooleanChunked> {
     }
 
     #[cfg(feature = "sort_multiple")]
-    fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
-        self.0.argsort_multiple(by, reverse)
+    fn arg_sort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
+        self.0.arg_sort_multiple(by, reverse)
     }
 }
 
@@ -262,8 +262,8 @@ impl SeriesTrait for SeriesWrap<BooleanChunked> {
         ChunkSort::sort_with(&self.0, options).into_series()
     }
 
-    fn argsort(&self, options: SortOptions) -> IdxCa {
-        ChunkSort::argsort(&self.0, options)
+    fn arg_sort(&self, options: SortOptions) -> IdxCa {
+        ChunkSort::arg_sort(&self.0, options)
     }
 
     fn null_count(&self) -> usize {
@@ -294,14 +294,6 @@ impl SeriesTrait for SeriesWrap<BooleanChunked> {
         self.0.is_not_null()
     }
 
-    fn is_unique(&self) -> PolarsResult<BooleanChunked> {
-        ChunkUnique::is_unique(&self.0)
-    }
-
-    fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
-        ChunkUnique::is_duplicated(&self.0)
-    }
-
     fn reverse(&self) -> Series {
         ChunkReverse::reverse(&self.0).into_series()
     }
