@@ -188,9 +188,7 @@ impl private::PrivateSeries for SeriesWrap<DurationChunked> {
         ))
     }
     fn divide(&self, _rhs: &Series) -> PolarsResult<Series> {
-        Err(PolarsError::ComputeError(
-            "cannot do division on logical".into(),
-        ))
+        self.0.deref().divide(_rhs.to_physical_repr().as_ref())
     }
     fn remainder(&self, _rhs: &Series) -> PolarsResult<Series> {
         Err(PolarsError::ComputeError(
@@ -201,8 +199,8 @@ impl private::PrivateSeries for SeriesWrap<DurationChunked> {
         self.0.group_tuples(multithreaded, sorted)
     }
     #[cfg(feature = "sort_multiple")]
-    fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
-        self.0.deref().argsort_multiple(by, reverse)
+    fn arg_sort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
+        self.0.deref().arg_sort_multiple(by, reverse)
     }
 }
 
@@ -377,8 +375,8 @@ impl SeriesTrait for SeriesWrap<DurationChunked> {
             .into_series()
     }
 
-    fn argsort(&self, options: SortOptions) -> IdxCa {
-        self.0.argsort(options)
+    fn arg_sort(&self, options: SortOptions) -> IdxCa {
+        self.0.arg_sort(options)
     }
 
     fn null_count(&self) -> usize {
@@ -403,14 +401,6 @@ impl SeriesTrait for SeriesWrap<DurationChunked> {
         self.0.arg_unique()
     }
 
-    fn arg_min(&self) -> Option<usize> {
-        self.0.arg_min()
-    }
-
-    fn arg_max(&self) -> Option<usize> {
-        self.0.arg_max()
-    }
-
     fn is_null(&self) -> BooleanChunked {
         self.0.is_null()
     }
@@ -419,14 +409,6 @@ impl SeriesTrait for SeriesWrap<DurationChunked> {
         self.0.is_not_null()
     }
 
-    fn is_unique(&self) -> PolarsResult<BooleanChunked> {
-        self.0.is_unique()
-    }
-
-    fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
-        self.0.is_duplicated()
-    }
-
     fn reverse(&self) -> Series {
         self.0
             .reverse()
@@ -445,12 +427,6 @@ impl SeriesTrait for SeriesWrap<DurationChunked> {
             .into_series()
     }
 
-    fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Series> {
-        self.0
-            .fill_null(strategy)
-            .map(|ca| ca.into_duration(self.0.time_unit()).into_series())
-    }
-
     fn _sum_as_series(&self) -> Series {
         self.0.sum_as_series().into_duration(self.0.time_unit())
     }
@@ -517,11 +493,6 @@ impl SeriesTrait for SeriesWrap<DurationChunked> {
             .unwrap()
             .clone()
     }
-    #[cfg(feature = "is_first")]
-    fn is_first(&self) -> PolarsResult<BooleanChunked> {
-        self.0.is_first()
-    }
-
     #[cfg(feature = "mode")]
     fn mode(&self) -> PolarsResult<Series> {
         self.0
