@@ -17,6 +17,7 @@ mod decimal;
 mod duration;
 mod floats;
 mod list;
+mod null;
 #[cfg(feature = "object")]
 mod object;
 #[cfg(feature = "dtype-struct")]
@@ -202,8 +203,8 @@ macro_rules! impl_dyn_series {
             }
 
             #[cfg(feature = "sort_multiple")]
-            fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
-                self.0.argsort_multiple(by, reverse)
+            fn arg_sort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
+                self.0.arg_sort_multiple(by, reverse)
             }
         }
 
@@ -397,8 +398,8 @@ macro_rules! impl_dyn_series {
                 ChunkSort::sort_with(&self.0, options).into_series()
             }
 
-            fn argsort(&self, options: SortOptions) -> IdxCa {
-                ChunkSort::argsort(&self.0, options)
+            fn arg_sort(&self, options: SortOptions) -> IdxCa {
+                ChunkSort::arg_sort(&self.0, options)
             }
 
             fn null_count(&self) -> usize {
@@ -429,14 +430,6 @@ macro_rules! impl_dyn_series {
                 self.0.is_not_null()
             }
 
-            fn is_unique(&self) -> PolarsResult<BooleanChunked> {
-                ChunkUnique::is_unique(&self.0)
-            }
-
-            fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
-                ChunkUnique::is_duplicated(&self.0)
-            }
-
             fn reverse(&self) -> Series {
                 ChunkReverse::reverse(&self.0).into_series()
             }
