@@ -97,8 +97,8 @@ impl private::PrivateSeries for SeriesWrap<Utf8Chunked> {
     }
 
     #[cfg(feature = "sort_multiple")]
-    fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
-        self.0.argsort_multiple(by, reverse)
+    fn arg_sort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
+        self.0.arg_sort_multiple(by, reverse)
     }
 }
 
@@ -248,8 +248,8 @@ impl SeriesTrait for SeriesWrap<Utf8Chunked> {
         ChunkSort::sort_with(&self.0, options).into_series()
     }
 
-    fn argsort(&self, options: SortOptions) -> IdxCa {
-        ChunkSort::argsort(&self.0, options)
+    fn arg_sort(&self, options: SortOptions) -> IdxCa {
+        ChunkSort::arg_sort(&self.0, options)
     }
 
     fn null_count(&self) -> usize {
@@ -272,14 +272,6 @@ impl SeriesTrait for SeriesWrap<Utf8Chunked> {
         ChunkUnique::arg_unique(&self.0)
     }
 
-    fn arg_min(&self) -> Option<usize> {
-        ArgAgg::arg_min(&self.0)
-    }
-
-    fn arg_max(&self) -> Option<usize> {
-        ArgAgg::arg_max(&self.0)
-    }
-
     fn is_null(&self) -> BooleanChunked {
         self.0.is_null()
     }
@@ -288,14 +280,6 @@ impl SeriesTrait for SeriesWrap<Utf8Chunked> {
         self.0.is_not_null()
     }
 
-    fn is_unique(&self) -> PolarsResult<BooleanChunked> {
-        ChunkUnique::is_unique(&self.0)
-    }
-
-    fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
-        ChunkUnique::is_duplicated(&self.0)
-    }
-
     fn reverse(&self) -> Series {
         ChunkReverse::reverse(&self.0).into_series()
     }
@@ -308,10 +292,6 @@ impl SeriesTrait for SeriesWrap<Utf8Chunked> {
         ChunkShift::shift(&self.0, periods).into_series()
     }
 
-    fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Series> {
-        ChunkFillNull::fill_null(&self.0, strategy).map(|ca| ca.into_series())
-    }
-
     fn _sum_as_series(&self) -> Series {
         ChunkAggSeries::sum_as_series(&self.0)
     }
@@ -337,11 +317,6 @@ impl SeriesTrait for SeriesWrap<Utf8Chunked> {
         RepeatBy::repeat_by(&self.0, by)
     }
 
-    #[cfg(feature = "is_first")]
-    fn is_first(&self) -> PolarsResult<BooleanChunked> {
-        self.0.is_first()
-    }
-
     #[cfg(feature = "mode")]
     fn mode(&self) -> PolarsResult<Series> {
         Ok(self.0.mode()?.into_series())
