@@ -56,7 +56,7 @@ fn write_anyvalue(
     f: &mut Vec<u8>,
     value: AnyValue,
     options: &SerializeOptions,
-    datetime_format: &str,
+    datetime_format: Option<&str>,
 ) {
     match value {
         AnyValue::Null => write!(f, "{}", &options.null),
@@ -93,6 +93,8 @@ fn write_anyvalue(
         }
         #[cfg(feature = "dtype-datetime")]
         AnyValue::Datetime(v, tu, tz) => {
+            // If this is a datetime, then datetime_format was either set or inferred.
+            let datetime_format = datetime_format.unwrap();
             let ndt = match tu {
                 TimeUnit::Nanoseconds => temporal_conversions::timestamp_ns_to_datetime(v),
                 TimeUnit::Microseconds => temporal_conversions::timestamp_us_to_datetime(v),
@@ -176,7 +178,7 @@ pub(crate) fn write<W: Write>(
     writer: &mut W,
     df: &DataFrame,
     chunk_size: usize,
-    options: &mut SerializeOptions,
+    options: &SerializeOptions,
 ) -> PolarsResult<()> {
     for s in df.get_columns() {
         let nested = match s.dtype() {
@@ -195,39 +197,28 @@ pub(crate) fn write<W: Write>(
         .map_err(|_| PolarsError::ComputeError("quote char leads invalid utf8".into()))?;
     let delimiter = char::from(options.delimiter);
 
-    // if datetime format not specified, infer the maximum required precision
-    if options.datetime_format.is_none() {
-        for col in df.get_columns() {
-            match col.dtype() {
-                DataType::Datetime(TimeUnit::Milliseconds, tz)
-                    // lowest precision; only set if it's not been inferred yet
-                    if options.datetime_format.is_none() =>
-                {
-                    options.datetime_format = match tz{
-                        Some(_) => Some("%FT%H:%M:%S.%3f%z".to_string()),
-                        None => Some("%FT%H:%M:%S.%3f".to_string()),
-                    };
-                }
-                DataType::Datetime(TimeUnit::Microseconds, tz) => {
-                    options.datetime_format = match tz{
-                        Some(_) => Some("%FT%H:%M:%S.%6f%z".to_string()),
-                        None => Some("%FT%H:%M:%S.%6f".to_string()),
-                    };
-                }
-                DataType::Datetime(TimeUnit::Nanoseconds, tz) => {
-                    options.datetime_format = match tz {
-                        Some(_) => Some("%FT%H:%M:%S.%9f%z".to_string()),
-                        None => Some("%FT%H:%M:%S.%9f".to_string()),
-                    };
-                    break; // highest precision; no need to check further
-                }
-                _ => {}
-            }
-        }
-    }
-    let datetime_format: &str = match &options.datetime_format {
-        Some(datetime_format) => datetime_format,
-        None => "%FT%H:%M:%S.%9f",
+    let formats: Option<Vec<Option<&str>>> = match &options.datetime_format {
+        None => Some(
+            df.get_columns()
+                .iter()
+                .map(|col| match col.dtype() {
+                    DataType::Datetime(TimeUnit::Milliseconds, tz) => match tz {
+                        Some(_) => Some("%FT%H:%M:%S.%3f%z"),
+                        None => Some("%FT%H:%M:%S.%3f"),
+                    },
+                    DataType::Datetime(TimeUnit::Microseconds, tz) => match tz {
+                        Some(_) => Some("%FT%H:%M:%S.%6f%z"),
+                        None => Some("%FT%H:%M:%S.%6f"),
+                    },
+                    DataType::Datetime(TimeUnit::Nanoseconds, tz) => match tz {
+                        Some(_) => Some("%FT%H:%M:%S.%9f%z"),
+                        None => Some("%FT%H:%M:%S.%9f"),
+                    },
+                    _ => None,
+                })
+                .collect::<Vec<_>>(),
+        ),
+        Some(_) => None,
     };
 
     let len = df.height();
@@ -267,7 +258,11 @@ pub(crate) fn write<W: Write>(
             let mut finished = false;
             // loop rows
             while !finished {
-                for col in &mut col_iters {
+                for (i, col) in &mut col_iters.iter_mut().enumerate() {
+                    let datetime_format = match &options.datetime_format {
+                        Some(datetime_format) => Some(datetime_format.as_str()),
+                        None => unsafe { *formats.as_ref().unwrap().get_unchecked(i) },
+                    };
                     match col.next() {
                         Some(value) => {
                             write_anyvalue(&mut write_buffer, value, options, datetime_format);
