@@ -114,15 +114,20 @@ where
 {
     use ALogicalPlan::*;
     let out = match lp_arena.get(node) {
-        #[cfg(feature = "parquet")]
+        #[cfg(any(feature = "parquet", feature = "ipc"))]
         FileSink { input, payload } => {
             let path = payload.path.as_ref().as_path();
             let input_schema = lp_arena.get(*input).schema(lp_arena);
             match &payload.file_type {
+                #[cfg(feature = "parquet")]
                 FileType::Parquet(options) => {
                     Box::new(ParquetSink::new(path, *options, input_schema.as_ref())?)
                         as Box<dyn Sink>
                 }
+                #[cfg(feature = "ipc")]
+                FileType::Ipc(options) => {
+                    Box::new(IpcSink::new(path, *options, input_schema.as_ref())?) as Box<dyn Sink>
+                }
             }
         }
         Join {
@@ -315,6 +320,12 @@ where
             };
             Box::new(op) as Box<dyn Operator>
         }
+        MapFunction { function, .. } => {
+            let op = operators::FunctionOperator {
+                function: function.clone(),
+            };
+            Box::new(op) as Box<dyn Operator>
+        }
 
         lp => {
             panic!("operator {lp:?} not (yet) supported")
