@@ -33,7 +33,7 @@ impl FunctionExpr {
             Ok(fld)
         };
 
-        #[cfg(any(feature = "rolling_window", feature = "trigonometry"))]
+        #[cfg(any(feature = "rolling_window", feature = "trigonometry", feature = "log"))]
         // set float supertype
         let float_dtype = || {
             map_dtype(&|dtype| match dtype {
@@ -93,10 +93,10 @@ impl FunctionExpr {
         };
 
         #[cfg(feature = "timezones")]
-        let cast_tz = |tz: &TimeZone| {
+        let cast_tz = |tz: Option<&TimeZone>| {
             try_map_dtype(&|dt| {
                 if let DataType::Datetime(tu, _) = dt {
-                    Ok(DataType::Datetime(*tu, Some(tz.clone())))
+                    Ok(DataType::Datetime(*tu, tz.cloned()))
                 } else {
                     Err(PolarsError::SchemaMisMatch(
                         format!("expected Datetime got {dt:?}").into(),
@@ -139,6 +139,8 @@ impl FunctionExpr {
                     Uppercase | Lowercase | Strip(_) | LStrip(_) | RStrip(_) => {
                         with_dtype(DataType::Utf8)
                     }
+                    #[cfg(feature = "string_from_radix")]
+                    FromRadix { .. } => with_dtype(DataType::Int32),
                 }
             }
             #[cfg(feature = "dtype-binary")]
@@ -159,7 +161,9 @@ impl FunctionExpr {
                     Truncate(..) => same_type().unwrap().dtype,
                     Round(..) => same_type().unwrap().dtype,
                     #[cfg(feature = "timezones")]
-                    CastTimezone(tz) | TzLocalize(tz) => return cast_tz(tz),
+                    CastTimezone(tz) => return cast_tz(tz.as_ref()),
+                    #[cfg(feature = "timezones")]
+                    TzLocalize(tz) => return cast_tz(Some(tz)),
                     DateRange { .. } => return super_type(),
                     Combine(tu) => DataType::Datetime(*tu, None),
                 };
@@ -210,11 +214,15 @@ impl FunctionExpr {
                                 .iter()
                                 .find(|fld| fld.name() == name.as_ref())
                                 .ok_or_else(|| {
-                                    PolarsError::NotFound(name.as_ref().to_string().into())
+                                    PolarsError::StructFieldNotFound(
+                                        name.as_ref().to_string().into(),
+                                    )
                                 })?;
                             Ok(fld.clone())
                         } else {
-                            Err(PolarsError::NotFound(name.as_ref().to_string().into()))
+                            Err(PolarsError::StructFieldNotFound(
+                                name.as_ref().to_string().into(),
+                            ))
                         }
                     }
                 }
@@ -222,7 +230,9 @@ impl FunctionExpr {
             #[cfg(feature = "top_k")]
             TopK { .. } => same_type(),
             Shift(..) | Reverse => same_type(),
-            IsNotNull | IsNull | Not | IsUnique | IsDuplicated => with_dtype(DataType::Boolean),
+            IsNotNull | IsNull | Not => with_dtype(DataType::Boolean),
+            #[cfg(feature = "is_unique")]
+            IsUnique | IsDuplicated => with_dtype(DataType::Boolean),
             #[cfg(feature = "diff")]
             Diff(_, _) => map_dtype(&|dt| match dt {
                 #[cfg(feature = "dtype-datetime")]
@@ -261,6 +271,16 @@ impl FunctionExpr {
                     }
                 })
             }
+            #[cfg(feature = "dot_product")]
+            Dot => map_dtype(&|dt| {
+                use DataType::*;
+                match dt {
+                    Int8 | Int16 | UInt16 | UInt8 => Int64,
+                    _ => dt.clone(),
+                }
+            }),
+            #[cfg(feature = "log")]
+            Entropy { .. } => float_dtype(),
         }
     }
 }
