@@ -242,12 +242,14 @@ pub fn to_alp(
             file_info,
             predicate,
             options,
+            cloud_options,
         } => ALogicalPlan::ParquetScan {
             path,
             file_info,
             output_schema: None,
             predicate: predicate.map(|expr| to_aexpr(expr, expr_arena)),
             options,
+            cloud_options,
         },
         LogicalPlan::DataFrameScan {
             df,
@@ -399,8 +401,7 @@ pub fn to_alp(
         LogicalPlan::Error { err, .. } => {
             // We just take the error. The LogicalPlan should not be used anymore once this
             // is taken.
-            let mut err = err.lock().unwrap();
-            return Err(err.take().unwrap());
+            return Err(err.take());
         }
         LogicalPlan::ExtContext {
             input,
@@ -418,6 +419,10 @@ pub fn to_alp(
                 schema,
             }
         }
+        LogicalPlan::FileSink { input, payload } => {
+            let input = to_alp(*input, expr_arena, lp_arena)?;
+            ALogicalPlan::FileSink { input, payload }
+        }
     };
     Ok(lp_arena.add(v))
 }
@@ -728,11 +733,13 @@ impl ALogicalPlan {
                 output_schema: _,
                 predicate,
                 options,
+                cloud_options,
             } => LogicalPlan::ParquetScan {
                 path,
                 file_info,
                 predicate: predicate.map(|n| node_to_expr(n, expr_arena)),
                 options,
+                cloud_options,
             },
             ALogicalPlan::DataFrameScan {
                 df,
@@ -894,6 +901,10 @@ impl ALogicalPlan {
                     schema,
                 }
             }
+            ALogicalPlan::FileSink { input, payload } => {
+                let input = Box::new(convert_to_lp(input, lp_arena));
+                LogicalPlan::FileSink { input, payload }
+            }
         }
     }
 }
