@@ -7,8 +7,9 @@ from pathlib import Path
 from typing import Any, BinaryIO, ContextManager, Iterator, TextIO, overload
 
 import polars.internals as pli
-from polars.datatypes import DataType
+from polars.datatypes import PolarsDataType
 from polars.dependencies import _FSSPEC_AVAILABLE, fsspec
+from polars.exceptions import NoDataError
 from polars.utils import normalise_filepath
 
 with suppress(ImportError):
@@ -16,6 +17,17 @@ with suppress(ImportError):
     from polars.polars import parquet_schema as _parquet_schema
 
 
+def _check_empty(b: BytesIO, context: str, read_position: int | None = None) -> BytesIO:
+    if not b.getbuffer().nbytes:
+        hint = (
+            f" (buffer position = {read_position}; try seek(0) before reading?)"
+            if context in ("StringIO", "BytesIO") and read_position
+            else ""
+        )
+        raise NoDataError(f"empty CSV data from {context}{hint}")
+    return b
+
+
 def _process_http_file(path: str, encoding: str | None = None) -> BytesIO:
     from urllib.request import urlopen
 
@@ -75,6 +87,7 @@ def _prepare_file_arg(
     fsspec too.
 
     """
+
     # Small helper to use a variable as context
     @contextmanager
     def managed_file(file: Any) -> Iterator[Any]:
@@ -90,21 +103,41 @@ def _prepare_file_arg(
 
     if isinstance(file, bytes):
         if has_non_utf8_non_utf8_lossy_encoding:
-            return BytesIO(file.decode(encoding_str).encode("utf8"))
+            return _check_empty(
+                BytesIO(file.decode(encoding_str).encode("utf8")),
+                context="bytes",
+            )
         if use_pyarrow:
-            return BytesIO(file)
+            return _check_empty(BytesIO(file), context="bytes")
 
     if isinstance(file, StringIO):
-        return BytesIO(file.getvalue().encode("utf8"))
+        return _check_empty(
+            BytesIO(file.read().encode("utf8")),
+            context="StringIO",
+            read_position=file.tell(),
+        )
 
     if isinstance(file, BytesIO):
         if has_non_utf8_non_utf8_lossy_encoding:
-            return BytesIO(file.getvalue().decode(encoding_str).encode("utf8"))
-        return managed_file(file)
+            return _check_empty(
+                BytesIO(file.read().decode(encoding_str).encode("utf8")),
+                context="BytesIO",
+                read_position=file.tell(),
+            )
+        return managed_file(
+            _check_empty(
+                b=file,
+                context="BytesIO",
+                read_position=file.tell(),
+            )
+        )
 
     if isinstance(file, Path):
         if has_non_utf8_non_utf8_lossy_encoding:
-            return BytesIO(file.read_bytes().decode(encoding_str).encode("utf8"))
+            return _check_empty(
+                BytesIO(file.read_bytes().decode(encoding_str).encode("utf8")),
+                context=f"Path ({file!r})",
+            )
         return managed_file(normalise_filepath(file))
 
     if isinstance(file, str):
@@ -136,12 +169,14 @@ def _prepare_file_arg(
         file = normalise_filepath(file)
         if has_non_utf8_non_utf8_lossy_encoding:
             with open(file, encoding=encoding_str) as f:
-                return BytesIO(f.read().encode("utf8"))
+                return _check_empty(
+                    BytesIO(f.read().encode("utf8")), context=f"{file!r}"
+                )
 
     return managed_file(file)
 
 
-def read_ipc_schema(file: str | BinaryIO | Path | bytes) -> dict[str, type[DataType]]:
+def read_ipc_schema(file: str | BinaryIO | Path | bytes) -> dict[str, PolarsDataType]:
     """
     Get a schema of the IPC file without reading data.
 
@@ -163,7 +198,7 @@ def read_ipc_schema(file: str | BinaryIO | Path | bytes) -> dict[str, type[DataT
 
 def read_parquet_schema(
     file: str | BinaryIO | Path | bytes,
-) -> dict[str, type[DataType]]:
+) -> dict[str, PolarsDataType]:
     """
     Get a schema of the Parquet file without reading data.
 
