@@ -1,8 +1,9 @@
 from __future__ import annotations
 
 import sys
+import warnings
 from datetime import date, datetime, time, timedelta
-from typing import TYPE_CHECKING, Any, Callable, Sequence, overload
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Sequence, overload
 
 from polars import internals as pli
 from polars.datatypes import (
@@ -23,17 +24,18 @@ from polars.datatypes import (
 )
 from polars.dependencies import _check_for_numpy
 from polars.dependencies import numpy as np
-from polars.internals.type_aliases import EpochTimeUnit
+from polars.internals.type_aliases import EpochTimeUnit, PolarsExprType
 from polars.utils import (
     _datetime_to_pl_timestamp,
     _time_to_pl_time,
     _timedelta_to_pl_timedelta,
+    deprecate_nonkeyword_arguments,
 )
 
 try:
     from polars.polars import arange as pyarange
+    from polars.polars import arg_sort_by as py_arg_sort_by
     from polars.polars import arg_where as py_arg_where
-    from polars.polars import argsort_by as pyargsort_by
     from polars.polars import as_struct as _as_struct
     from polars.polars import coalesce_exprs as _coalesce_exprs
     from polars.polars import col as pycol
@@ -72,19 +74,22 @@ else:
 if TYPE_CHECKING:
     from polars.internals.type_aliases import (
         IntoExpr,
+        PythonLiteral,
         RollingInterpolationMethod,
         TimeUnit,
     )
 
 
 def col(
-    name: str
-    | Sequence[str]
-    | Sequence[PolarsDataType]
-    | set[PolarsDataType]
-    | frozenset[PolarsDataType]
-    | pli.Series
-    | PolarsDataType,
+    name: (
+        str
+        | Sequence[str]
+        | Sequence[PolarsDataType]
+        | set[PolarsDataType]
+        | frozenset[PolarsDataType]
+        | pli.Series
+        | PolarsDataType
+    ),
 ) -> pli.Expr:
     """
     Return an expression representing a column in a DataFrame.
@@ -706,7 +711,7 @@ def mean(column: pli.Series) -> float:
     ...
 
 
-def mean(column: str | pli.Series) -> pli.Expr | float:
+def mean(column: str | pli.Series) -> pli.Expr | float | None:
     """
     Get the mean value.
 
@@ -774,7 +779,7 @@ def median(column: pli.Series) -> float | int:
     ...
 
 
-def median(column: str | pli.Series) -> pli.Expr | float | int:
+def median(column: str | pli.Series) -> pli.Expr | float | int | None:
     """
     Get the median value.
 
@@ -1126,7 +1131,7 @@ def lit(
         tu = "us"
         e = lit(_datetime_to_pl_timestamp(value, tu)).cast(Datetime(tu))
         if value.tzinfo is not None:
-            return e.dt.tz_localize(str(value.tzinfo))
+            return e.dt.replace_time_zone(str(value.tzinfo))
         else:
             return e
 
@@ -1257,7 +1262,7 @@ def cumsum(
     │ 2   ┆ 4   ┆ 6   ┆ {2,8}     │
     └─────┴─────┴─────┴───────────┘
 
-    """  # noqa E501
+    """  # noqa: W505
     if isinstance(column, pli.Series):
         return column.cumsum()
     elif isinstance(column, str):
@@ -1409,6 +1414,7 @@ def map(
     )
 
 
+@deprecate_nonkeyword_arguments(allowed_args=["exprs", "f", "return_dtype"])
 def apply(
     exprs: Sequence[str | pli.Expr],
     f: Callable[[Sequence[pli.Series]], pli.Series | Any],
@@ -1512,6 +1518,7 @@ def reduce(
     return pli.wrap_expr(pyreduce(f, exprs))
 
 
+@deprecate_nonkeyword_arguments()
 def cumfold(
     acc: IntoExpr,
     f: Callable[[pli.Series, pli.Series], pli.Series],
@@ -1541,7 +1548,7 @@ def cumfold(
     If you simply want the first encountered expression as accumulator,
     consider using ``cumreduce``.
 
-    """  # noqa E501
+    """  # noqa: W505
     # in case of pl.col("*")
     acc = pli.expr_to_lit_or_expr(acc, str_to_lit=True)
     if isinstance(exprs, pli.Expr):
@@ -1568,7 +1575,7 @@ def cumreduce(
     exprs
         Expressions to aggregate over. May also be a wildcard expression.
 
-    """  # noqa E501
+    """  # noqa: W505
     # in case of pl.col("*")
     if isinstance(exprs, pli.Expr):
         exprs = [exprs]
@@ -1831,7 +1838,8 @@ def arange(
         )
 
 
-def argsort_by(
+@deprecate_nonkeyword_arguments()
+def arg_sort_by(
     exprs: pli.Expr | str | Sequence[pli.Expr | str],
     reverse: Sequence[bool] | bool = False,
 ) -> pli.Expr:
@@ -1855,7 +1863,37 @@ def argsort_by(
     if isinstance(reverse, bool):
         reverse = [reverse] * len(exprs)
     exprs = pli.selection_to_pyexpr_list(exprs)
-    return pli.wrap_expr(pyargsort_by(exprs, reverse))
+    return pli.wrap_expr(py_arg_sort_by(exprs, reverse))
+
+
+def argsort_by(
+    exprs: pli.Expr | str | Sequence[pli.Expr | str],
+    reverse: Sequence[bool] | bool = False,
+) -> pli.Expr:
+    """
+    Find the indexes that would sort the columns.
+
+    Argsort by multiple columns. The first column will be used for the ordering.
+    If there are duplicates in the first column, the second column will be used to
+    determine the ordering and so on.
+
+    .. deprecated:: 0.16.5
+        `argsort_by` will be removed in favour of `arg_sort_by`.
+
+    Parameters
+    ----------
+    exprs
+        Columns use to determine the ordering.
+    reverse
+        Default is ascending.
+
+    """
+    warnings.warn(
+        "`argsort_by()` is deprecated in favor of `arg_sort_by()`",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    return pli.arg_sort_by(exprs, reverse)
 
 
 def duration(
@@ -1909,7 +1947,7 @@ def duration(
     │ 00:00:00   ┆ 00:00:00   ┆                     ┆ 00:00:00.002 ┆                     │
     └────────────┴────────────┴─────────────────────┴──────────────┴─────────────────────┘
 
-    """  # noqa: E501
+    """  # noqa: W505
     if hours is not None:
         hours = pli.expr_to_lit_or_expr(hours, str_to_lit=False)._pyexpr
     if minutes is not None:
@@ -2026,6 +2064,7 @@ def _date(
     return _datetime(year, month, day).cast(Date).alias("date")
 
 
+@deprecate_nonkeyword_arguments()
 def concat_str(exprs: Sequence[pli.Expr | str] | pli.Expr, sep: str = "") -> pli.Expr:
     """
     Horizontally concat Utf8 Series in linear time. Non-Utf8 columns are cast to Utf8.
@@ -2246,20 +2285,31 @@ def collect_all(
 
 
 def select(
-    exprs: str | pli.Expr | Sequence[str | pli.Expr] | pli.Series,
-    **named_exprs: Any,
+    exprs: (
+        str
+        | PolarsExprType
+        | PythonLiteral
+        | pli.Series
+        | Iterable[str | PolarsExprType | PythonLiteral | pli.Series | None]
+        | None
+    ) = None,
+    *more_exprs: str | PolarsExprType | PythonLiteral | pli.Series | None,
+    **named_exprs: str | PolarsExprType | PythonLiteral | pli.Series | None,
 ) -> pli.DataFrame:
     """
     Run polars expressions without a context.
 
-    This is syntactic sugar for running `df.select` on an empty DataFrame.
+    This is syntactic sugar for running ``df.select`` on an empty DataFrame.
 
     Parameters
     ----------
     exprs
-        Expressions to run
+        Expression or expressions to run.
+    *more_exprs
+        Additional expressions to run, specified as positional arguments.
     **named_exprs
-        Named expressions, provided as kwargs.
+        Additional expressions to run, specified as keyword arguments. The expressions
+        will be renamed to the keyword used.
 
     Returns
     -------
@@ -2269,11 +2319,7 @@ def select(
     --------
     >>> foo = pl.Series("foo", [1, 2, 3])
     >>> bar = pl.Series("bar", [3, 2, 1])
-    >>> pl.select(
-    ...     [
-    ...         pl.min([foo, bar]),
-    ...     ]
-    ... )
+    >>> pl.select(pl.min([foo, bar]))
     shape: (3, 1)
     ┌─────┐
     │ min │
@@ -2286,7 +2332,7 @@ def select(
     └─────┘
 
     """
-    return pli.DataFrame([]).select(exprs, **named_exprs)
+    return pli.DataFrame().select(exprs, *more_exprs, **named_exprs)
 
 
 @overload
@@ -2316,6 +2362,7 @@ def struct(
     ...
 
 
+@deprecate_nonkeyword_arguments()
 def struct(
     exprs: Sequence[pli.Expr | str | pli.Series] | pli.Expr | pli.Series,
     eager: bool = False,
