@@ -932,19 +932,6 @@ impl PyDataFrame {
         Ok(PySeries { series: s })
     }
 
-    pub fn drop_nulls(&self, subset: Option<Vec<String>>) -> PyResult<Self> {
-        let df = self
-            .df
-            .drop_nulls(subset.as_ref().map(|s| s.as_ref()))
-            .map_err(PyPolarsErr::from)?;
-        Ok(df.into())
-    }
-
-    pub fn drop(&self, name: &str) -> PyResult<Self> {
-        let df = self.df.drop(name).map_err(PyPolarsErr::from)?;
-        Ok(PyDataFrame::new(df))
-    }
-
     pub fn select_at_idx(&self, idx: usize) -> Option<PySeries> {
         self.df.select_at_idx(idx).map(|s| PySeries::new(s.clone()))
     }
@@ -1059,8 +1046,19 @@ impl PyDataFrame {
         Ok(df.into())
     }
 
-    pub fn groupby_apply(&self, by: Vec<&str>, lambda: PyObject) -> PyResult<Self> {
-        let gb = self.df.groupby(&by).map_err(PyPolarsErr::from)?;
+    pub fn groupby_apply(
+        &self,
+        by: Vec<&str>,
+        lambda: PyObject,
+        maintain_order: bool,
+    ) -> PyResult<Self> {
+        let gb = if maintain_order {
+            self.df.groupby_stable(&by)
+        } else {
+            self.df.groupby(&by)
+        }
+        .map_err(PyPolarsErr::from)?;
+
         let function = move |df: DataFrame| {
             Python::with_gil(|py| {
                 // get the pypolars module
@@ -1164,25 +1162,6 @@ impl PyDataFrame {
         self.df.shift(periods).into()
     }
 
-    #[pyo3(signature = (maintain_order, subset, keep))]
-    pub fn unique(
-        &self,
-        py: Python,
-        maintain_order: bool,
-        subset: Option<Vec<String>>,
-        keep: Wrap<UniqueKeepStrategy>,
-    ) -> PyResult<Self> {
-        let df = py.allow_threads(|| {
-            let subset = subset.as_ref().map(|v| v.as_ref());
-            match maintain_order {
-                true => self.df.unique_stable(subset, keep.0),
-                false => self.df.unique(subset, keep.0),
-            }
-            .map_err(PyPolarsErr::from)
-        })?;
-        Ok(df.into())
-    }
-
     pub fn lazy(&self) -> PyLazyFrame {
         self.df.clone().lazy().into()
     }
