@@ -9,10 +9,12 @@ import zlib
 from datetime import date, datetime, time, timedelta, timezone
 from pathlib import Path
 
+import numpy as np
 import pytest
 
 import polars as pl
 from polars import DataType
+from polars.exceptions import NoDataError
 from polars.internals.type_aliases import TimeUnit
 from polars.testing import (
     assert_frame_equal,
@@ -27,13 +29,13 @@ def foods_file_path(io_files_path: Path) -> Path:
     return io_files_path / "foods1.csv"
 
 
-@pytest.mark.skip("Needs fix: https://github.com/pola-rs/polars/issues/6474")
 def test_quoted_date() -> None:
     csv = textwrap.dedent(
-        """a,b
-    "2022-01-01",1
-    "2022-01-02",2
-    """
+        """\
+        a,b
+        "2022-01-01",1
+        "2022-01-02",2
+        """
     )
     result = pl.read_csv(csv.encode(), parse_dates=True)
     expected = pl.DataFrame({"a": [date(2022, 1, 1), date(2022, 1, 2)], "b": [1, 2]})
@@ -90,6 +92,14 @@ def test_csv_null_values() -> None:
     df = pl.read_csv(f, null_values="na")
     assert df.rows() == [(None, "b", "c"), ("a", None, "c")]
 
+    # note: after reading, the buffer position in StringIO will have been
+    # advanced; reading again will raise NoDataError, so we provide a hint
+    # in the error string about this, suggesting "seek(0)" as a possible fix
+    with pytest.raises(
+        NoDataError, match=r"empty CSV data .* position = 20; try seek\(0\)"
+    ):
+        pl.read_csv(f)
+
     out = io.BytesIO()
     df.write_csv(out, null_value="na")
     assert csv == out.getvalue().decode("ascii")
@@ -175,6 +185,7 @@ def test_csv_missing_utf8_is_empty_string() -> None:
         (None, None, None, None, None, None, None),
     ]
 
+    f.seek(0)
     df = pl.read_csv(
         f,
         null_values=["na", r"\N"],
@@ -369,6 +380,7 @@ def test_read_csv_encoding() -> None:
         bytesio = io.BytesIO(bts)
 
         for use_pyarrow in (False, True):
+            bytesio.seek(0)
             for file in [file_path, file_str, bts, bytesio]:
                 assert_series_equal(
                     pl.read_csv(
@@ -707,9 +719,7 @@ def test_quoting_round_trip() -> None:
         }
     )
     df.write_csv(f)
-    f.seek(0)
     read_df = pl.read_csv(f)
-
     assert_frame_equal(read_df, df)
 
 
@@ -889,16 +899,16 @@ def test_datetime_format_tz_aware(fmt: str, expected: str, tzinfo: timezone) ->
         (
             "ns",
             "us",
-            "x,y\n2022-09-04T10:30:45.123000000,2022-09-04T10:30:45.123000000\n",
+            "x,y\n2022-09-04T10:30:45.123000000,2022-09-04T10:30:45.123000\n",
         ),
         (
             "ns",
             "ms",
-            "x,y\n2022-09-04T10:30:45.123000000,2022-09-04T10:30:45.123000000\n",
+            "x,y\n2022-09-04T10:30:45.123000000,2022-09-04T10:30:45.123\n",
         ),
         ("us", "us", "x,y\n2022-09-04T10:30:45.123000,2022-09-04T10:30:45.123000\n"),
-        ("us", "ms", "x,y\n2022-09-04T10:30:45.123000,2022-09-04T10:30:45.123000\n"),
-        ("ms", "us", "x,y\n2022-09-04T10:30:45.123000,2022-09-04T10:30:45.123000\n"),
+        ("us", "ms", "x,y\n2022-09-04T10:30:45.123000,2022-09-04T10:30:45.123\n"),
+        ("ms", "us", "x,y\n2022-09-04T10:30:45.123,2022-09-04T10:30:45.123000\n"),
         ("ms", "ms", "x,y\n2022-09-04T10:30:45.123,2022-09-04T10:30:45.123\n"),
     ],
 )
@@ -918,6 +928,18 @@ def test_datetime_format_inferred_precision(
     assert expected == df.write_csv()
 
 
+def test_inferred_datetime_format_mixed() -> None:
+    ts = pl.date_range(datetime(2000, 1, 1), datetime(2000, 1, 2))
+    df = pl.DataFrame({"naive": ts, "aware": ts.dt.replace_time_zone("UTC")})
+    result = df.write_csv()
+    expected = (
+        "naive,aware\n"
+        "2000-01-01T00:00:00.000000,2000-01-01T00:00:00.000000+0000\n"
+        "2000-01-02T00:00:00.000000,2000-01-02T00:00:00.000000+0000\n"
+    )
+    assert result == expected
+
+
 @pytest.mark.parametrize(
     ("fmt", "expected"),
     [
@@ -969,6 +991,7 @@ def test_skip_rows_different_field_len() -> None:
         )
     )
     for empty_string, missing_value in ((True, ""), (False, None)):
+        csv.seek(0)
         assert pl.read_csv(
             csv, skip_rows_after_header=2, missing_utf8_is_empty_string=empty_string
         ).to_dict(False) == {
@@ -1153,3 +1176,30 @@ def test_read_web_file() -> None:
     url = "https://raw.githubusercontent.com/pola-rs/polars/master/examples/datasets/foods1.csv"
     df = pl.read_csv(url)
     assert df.shape == (27, 4)
+
+
+@pytest.mark.slow()
+def test_csv_multiline_splits() -> None:
+    # create a very unlikely csv file with many multilines in a
+    # single field (e.g. 5000). polars must reject multi-threading here
+    # as it cannot find proper file chunks without sequentially parsing.
+
+    np.random.seed(0)
+    f = io.BytesIO()
+
+    def some_multiline_str(n: int) -> str:
+        strs = []
+        strs.append('"')
+        # sample between 0 and 5 so that it is likely
+        # the multiline field also go 3 separators.
+        for length in np.random.randint(0, 5, n):
+            strs.append(f"{'xx,' * length}")
+
+        strs.append('"')
+        return "\n".join(strs)
+
+    for _ in range(4):
+        f.write(f"field1,field2,{some_multiline_str(5000)}\n".encode())
+
+    f.seek(0)
+    assert pl.read_csv(f, has_header=False).shape == (4, 3)
