@@ -64,9 +64,27 @@ def test_groupby() -> None:
     ]
     # assert sorted(df.groupby("b").quantile(0.5).rows()) == ...
 
-    # Invalid input: `by` not specified as a sequence
-    with pytest.raises(TypeError):
-        df.groupby("a", "b")  # type: ignore[arg-type, misc]
+
+def test_groupby_args() -> None:
+    df = pl.DataFrame(
+        {
+            "a": ["a", "b", "a", "b", "b", "c"],
+            "b": [1, 2, 3, 4, 5, 6],
+            "c": [6, 5, 4, 3, 2, 1],
+        }
+    )
+
+    # Single column name
+    assert df.groupby("a").agg("b").columns == ["a", "b"]
+    # Column names as list
+    expected = ["a", "b", "c"]
+    assert df.groupby(["a", "b"]).agg("c").columns == expected
+    # Column names as positional arguments
+    assert df.groupby("a", "b").agg("c").columns == expected
+    # With keyword argument
+    assert df.groupby("a", "b", maintain_order=True).agg("c").columns == expected
+    # Mixed
+    assert df.groupby(["a"], "b", maintain_order=True).agg("c").columns == expected
 
 
 def test_groupby_iteration() -> None:
@@ -104,7 +122,8 @@ def test_groupby_iteration() -> None:
 
 
 def bad_agg_parameters() -> list[Any]:
-    return [[("b", "sum")], [("b", ["sum"])], {"b": "sum"}, {"b": ["sum"]}]
+    """Currently, IntoExpr and Iterable[IntoExpr] are supported."""
+    return [[("b", "sum")], [("b", ["sum"])], str, "b".join]
 
 
 def good_agg_parameters() -> list[pl.Expr | list[pl.Expr]]:
@@ -295,7 +314,7 @@ def test_groupby_signed_transmutes() -> None:
         }
 
 
-def test_argsort_sort_by_groups_update__4360() -> None:
+def test_arg_sort_sort_by_groups_update__4360() -> None:
     df = pl.DataFrame(
         {
             "group": ["a"] * 3 + ["b"] * 3 + ["c"] * 3,
@@ -305,11 +324,11 @@ def test_argsort_sort_by_groups_update__4360() -> None:
     )
 
     out = df.with_columns(
-        pl.col("col2").arg_sort().over("group").alias("col2_argsort")
+        pl.col("col2").arg_sort().over("group").alias("col2_arg_sort")
     ).with_columns(
         [
             pl.col("col1")
-            .sort_by(pl.col("col2_argsort"))
+            .sort_by(pl.col("col2_arg_sort"))
             .over("group")
             .alias("result_a"),
             pl.col("col1")
@@ -505,3 +524,23 @@ def test_overflow_mean_partitioned_groupby_5194(dtype: pl.PolarsDataType) -> Non
     assert df.groupby("group").agg(pl.col("data").mean()).sort(by="group").to_dict(
         False
     ) == {"group": [1, 2], "data": [10000000.0, 10000000.0]}
+
+
+def test_groupby_dynamic_elementwise_following_mean_agg_6904() -> None:
+    assert (
+        pl.DataFrame(
+            {
+                "a": [
+                    datetime(2021, 1, 1) + timedelta(seconds=2**i) for i in range(5)
+                ],
+                "b": [float(i) for i in range(5)],
+            }
+        )
+        .lazy()
+        .groupby_dynamic("a", every="10s", period="100s")
+        .agg([pl.col("b").mean().sin().alias("c")])
+        .collect()
+    ).to_dict(False) == {
+        "a": [datetime(2021, 1, 1, 0, 0), datetime(2021, 1, 1, 0, 0, 10)],
+        "c": [0.9092974268256817, -0.7568024953079282],
+    }
