@@ -1,7 +1,6 @@
 from __future__ import annotations
 
-import os
-from datetime import date, datetime
+from datetime import date, datetime, time
 from functools import reduce
 from operator import add
 from string import ascii_letters
@@ -36,7 +35,7 @@ def test_lazy() -> None:
 
     # test if pl.list is available, this is `to_list` re-exported as list
     eager = df.groupby("a").agg(pl.list("b"))
-    assert sorted(eager.rows()) == [(1, [1.0]), (2, [2.0]), (3, [3.0])]
+    assert sorted(eager.rows()) == [(1, [[1.0]]), (2, [[2.0]]), (3, [[3.0]])]
 
     # profile lazyframe operation/plan
     lazy = df.lazy().groupby("a").agg(pl.list("b"))
@@ -68,7 +67,7 @@ def test_apply() -> None:
     new = df.lazy().with_columns(col("a").map(lambda s: s * 2).alias("foo")).collect()
 
     expected = df.clone().with_columns((pl.col("a") * 2).alias("foo"))
-    assert new.frame_equal(expected)
+    assert_frame_equal(new, expected)
 
 
 def test_add_eager_column() -> None:
@@ -163,11 +162,11 @@ def test_filter_str() -> None:
     # last row based on a filter
     result = q.filter(pl.col("bools")).select(pl.last("*")).collect()
     expected = pl.DataFrame({"time": ["11:13:00"], "bools": [True]})
-    assert result.frame_equal(expected)
+    assert_frame_equal(result, expected)
 
     # last row based on a filter
     result = q.filter("bools").select(pl.last("*")).collect()
-    assert result.frame_equal(expected)
+    assert_frame_equal(result, expected)
 
 
 def test_apply_custom_function() -> None:
@@ -206,7 +205,7 @@ def test_apply_custom_function() -> None:
         }
     )
     expected = expected.with_columns(pl.col("cars_count").cast(pl.UInt32))
-    assert a.frame_equal(expected)
+    assert_frame_equal(a, expected)
 
 
 def test_groupby() -> None:
@@ -215,17 +214,17 @@ def test_groupby() -> None:
     expected = pl.DataFrame({"groups": ["a", "b"], "a": [1.0, 3.5]})
 
     out = df.lazy().groupby("groups").agg(pl.mean("a")).collect()
-    assert out.sort(by="groups").frame_equal(expected)
+    assert_frame_equal(out.sort(by="groups"), expected)
 
     # refer to column via pl.Expr
     out = df.lazy().groupby(pl.col("groups")).agg(pl.mean("a")).collect()
-    assert out.sort(by="groups").frame_equal(expected)
+    assert_frame_equal(out.sort(by="groups"), expected)
 
 
 def test_shift(fruits_cars: pl.DataFrame) -> None:
     df = pl.DataFrame({"a": [1, 2, 3, 4, 5], "b": [1, 2, 3, 4, 5]})
     out = df.select(col("a").shift(1))
-    assert out["a"].series_equal(pl.Series("a", [None, 1, 2, 3, 4]), null_equal=True)
+    assert_series_equal(out["a"], pl.Series("a", [None, 1, 2, 3, 4]))
 
     res = fruits_cars.lazy().shift(2).collect()
 
@@ -237,7 +236,7 @@ def test_shift(fruits_cars: pl.DataFrame) -> None:
             "cars": [None, None, "beetle", "audi", "beetle"],
         }
     )
-    res.frame_equal(expected, null_equal=True)
+    assert_frame_equal(res, expected)
 
     # negative value
     res = fruits_cars.lazy().shift(-2).collect()
@@ -262,34 +261,38 @@ def test_arange() -> None:
     df = pl.DataFrame({"a": [1, 1, 1]}).lazy()
     result = df.filter(pl.col("a") >= pl.arange(0, 3)).collect()
     expected = pl.DataFrame({"a": [1, 1]})
-    assert result.frame_equal(expected)
+    assert_frame_equal(result, expected)
 
 
 def test_arg_unique() -> None:
     df = pl.DataFrame({"a": [4, 1, 4]})
     col_a_unique = df.select(col("a").arg_unique())["a"]
-    assert col_a_unique.series_equal(pl.Series("a", [0, 1]).cast(pl.UInt32))
+    assert_series_equal(col_a_unique, pl.Series("a", [0, 1]).cast(pl.UInt32))
 
 
 def test_is_unique() -> None:
     df = pl.DataFrame({"a": [4, 1, 4]})
-    assert df.select(col("a").is_unique())["a"].series_equal(
-        pl.Series("a", [False, True, False])
-    )
+    result = df.select(col("a").is_unique())["a"]
+    assert_series_equal(result, pl.Series("a", [False, True, False]))
 
 
 def test_is_first() -> None:
     df = pl.DataFrame({"a": [4, 1, 4]})
-    assert df.select(col("a").is_first())["a"].series_equal(
-        pl.Series("a", [True, True, False])
-    )
+    result = df.select(col("a").is_first())["a"]
+    assert_series_equal(result, pl.Series("a", [True, True, False]))
+
+    # struct
+    df = pl.DataFrame({"a": [1, 2, 3, 2, None, 2, 1], "b": [0, 2, 3, 2, None, 2, 0]})
+
+    assert df.select(pl.struct(["a", "b"]).is_first()).to_dict(False) == {
+        "a": [True, True, True, False, True, False, False]
+    }
 
 
 def test_is_duplicated() -> None:
     df = pl.DataFrame({"a": [4, 1, 4]})
-    assert df.select(col("a").is_duplicated())["a"].series_equal(
-        pl.Series("a", [True, False, True])
-    )
+    result = df.select(col("a").is_duplicated())["a"]
+    assert_series_equal(result, pl.Series("a", [True, False, True]))
 
 
 def test_arg_sort() -> None:
@@ -353,7 +356,7 @@ def test_inspect(capsys: CaptureFixture[str]) -> None:
 
 def test_fetch(fruits_cars: pl.DataFrame) -> None:
     res = fruits_cars.lazy().select("*").fetch(2)
-    assert res.frame_equal(res[:2])
+    assert_frame_equal(res, res[:2])
 
 
 def test_window_deadlock() -> None:
@@ -455,7 +458,7 @@ def test_head_groupby() -> None:
     out = (
         df.sort(by="price", reverse=True)
         .groupby(keys, maintain_order=True)
-        .agg([col("*").exclude(keys).head(2).list().keep_name()])
+        .agg([col("*").exclude(keys).head(2).keep_name()])
         .explode(col("*").exclude(keys))
     )
 
@@ -472,12 +475,14 @@ def test_head_groupby() -> None:
         {"letters": ["c", "c", "a", "c", "a", "b"], "nrs": [1, 2, 3, 4, 5, 6]}
     )
     out = df.groupby("letters").tail(2).sort("letters")
-    assert out.frame_equal(
-        pl.DataFrame({"letters": ["a", "a", "b", "c", "c"], "nrs": [3, 5, 6, 2, 4]})
+    assert_frame_equal(
+        out,
+        pl.DataFrame({"letters": ["a", "a", "b", "c", "c"], "nrs": [3, 5, 6, 2, 4]}),
     )
     out = df.groupby("letters").head(2).sort("letters")
-    assert out.frame_equal(
-        pl.DataFrame({"letters": ["a", "a", "b", "c", "c"], "nrs": [3, 5, 6, 1, 2]})
+    assert_frame_equal(
+        out,
+        pl.DataFrame({"letters": ["a", "a", "b", "c", "c"], "nrs": [3, 5, 6, 1, 2]}),
     )
 
 
@@ -506,30 +511,30 @@ def test_len() -> None:
 
 def test_cum_agg() -> None:
     df = pl.DataFrame({"a": [1, 2, 3, 2]})
-    assert df.select(pl.col("a").cumsum())["a"].series_equal(
-        pl.Series("a", [1, 3, 6, 8])
+    assert_series_equal(
+        df.select(pl.col("a").cumsum())["a"], pl.Series("a", [1, 3, 6, 8])
     )
-    assert df.select(pl.col("a").cummin())["a"].series_equal(
-        pl.Series("a", [1, 1, 1, 1])
+    assert_series_equal(
+        df.select(pl.col("a").cummin())["a"], pl.Series("a", [1, 1, 1, 1])
     )
-    assert df.select(pl.col("a").cummax())["a"].series_equal(
-        pl.Series("a", [1, 2, 3, 3])
+    assert_series_equal(
+        df.select(pl.col("a").cummax())["a"], pl.Series("a", [1, 2, 3, 3])
     )
-    assert df.select(pl.col("a").cumprod())["a"].series_equal(
-        pl.Series("a", [1, 2, 6, 12])
+    assert_series_equal(
+        df.select(pl.col("a").cumprod())["a"], pl.Series("a", [1, 2, 6, 12])
     )
 
 
 def test_floor() -> None:
     df = pl.DataFrame({"a": [1.8, 1.2, 3.0]})
     col_a_floor = df.select(pl.col("a").floor())["a"]
-    assert col_a_floor.series_equal(pl.Series("a", [1, 1, 3]).cast(pl.Float64))
+    assert_series_equal(col_a_floor, pl.Series("a", [1, 1, 3]).cast(pl.Float64))
 
 
 def test_round() -> None:
     df = pl.DataFrame({"a": [1.8, 1.2, 3.0]})
     col_a_rounded = df.select(pl.col("a").round(decimals=0))["a"]
-    assert col_a_rounded.series_equal(pl.Series("a", [2, 1, 3]).cast(pl.Float64))
+    assert_series_equal(col_a_rounded, pl.Series("a", [2, 1, 3]).cast(pl.Float64))
 
 
 def test_dot() -> None:
@@ -539,23 +544,14 @@ def test_dot() -> None:
 
 def test_sort() -> None:
     df = pl.DataFrame({"a": [1, 2, 3, 2]})
-    assert df.select(pl.col("a").sort())["a"].series_equal(pl.Series("a", [1, 2, 2, 3]))
-
-
-def test_drop_nulls() -> None:
-    df = pl.DataFrame({"nrs": [None, 1, 2, 3, None, 4, 5, None]})
-    assert df.select(col("nrs").drop_nulls()).to_dict(as_series=False) == {
-        "nrs": [1, 2, 3, 4, 5]
-    }
-
-    df = pl.DataFrame({"foo": [1, 2, 3], "bar": [6, None, 8], "ham": ["a", "b", "c"]})
-    expected = pl.DataFrame({"foo": [1, 3], "bar": [6, 8], "ham": ["a", "c"]})
-    df.lazy().drop_nulls().collect().frame_equal(expected)
+    assert_series_equal(
+        df.select(pl.col("a").sort())["a"], pl.Series("a", [1, 2, 2, 3])
+    )
 
 
 def test_all_expr() -> None:
     df = pl.DataFrame({"nrs": [1, 2, 3, 4, 5, None]})
-    assert df.select([pl.all()]).frame_equal(df)
+    assert_frame_equal(df.select([pl.all()]), df)
 
 
 def test_any_expr(fruits_cars: pl.DataFrame) -> None:
@@ -612,21 +608,15 @@ def test_interpolate() -> None:
 
 def test_fill_nan() -> None:
     df = pl.DataFrame({"a": [1.0, np.nan, 3.0]})
-    assert df.fill_nan(2.0)["a"].series_equal(pl.Series("a", [1.0, 2.0, 3.0]))
-    assert (
-        df.lazy()
-        .fill_nan(2.0)
-        .collect()["a"]
-        .series_equal(pl.Series("a", [1.0, 2.0, 3.0]))
+    assert_series_equal(df.fill_nan(2.0)["a"], pl.Series("a", [1.0, 2.0, 3.0]))
+    assert_series_equal(
+        df.lazy().fill_nan(2.0).collect()["a"], pl.Series("a", [1.0, 2.0, 3.0])
     )
-    assert (
-        df.lazy()
-        .fill_nan(None)
-        .collect()["a"]
-        .series_equal(pl.Series("a", [1.0, None, 3.0]), null_equal=True)
+    assert_series_equal(
+        df.lazy().fill_nan(None).collect()["a"], pl.Series("a", [1.0, None, 3.0])
     )
-    assert df.select(pl.col("a").fill_nan(2))["a"].series_equal(
-        pl.Series("a", [1.0, 2.0, 3.0])
+    assert_series_equal(
+        df.select(pl.col("a").fill_nan(2))["a"], pl.Series("a", [1.0, 2.0, 3.0])
     )
     # nearest
     assert pl.Series([None, 1, None, None, None, -8, None, None, 10]).interpolate(
@@ -651,7 +641,7 @@ def test_fill_null() -> None:
 def test_backward_fill() -> None:
     df = pl.DataFrame({"a": [1.0, None, 3.0]})
     col_a_backward_fill = df.select([pl.col("a").backward_fill()])["a"]
-    assert col_a_backward_fill.series_equal(pl.Series("a", [1, 3, 3]).cast(pl.Float64))
+    assert_series_equal(col_a_backward_fill, pl.Series("a", [1, 3, 3]).cast(pl.Float64))
 
 
 def test_take(fruits_cars: pl.DataFrame) -> None:
@@ -689,10 +679,38 @@ def test_take(fruits_cars: pl.DataFrame) -> None:
 
 def test_select_by_col_list(fruits_cars: pl.DataFrame) -> None:
     df = fruits_cars
-    out = df.select(col(["A", "B"]).sum())
-    assert out.columns == ["A", "B"]
-    assert out.shape == (1, 2)
-    assert out.row(0) == (15, 15)
+    result = df.select(col(["A", "B"]).sum())
+    expected = pl.DataFrame({"A": 15, "B": 15})
+    assert_frame_equal(result, expected)
+
+
+def test_select_args_kwargs() -> None:
+    df = pl.DataFrame({"foo": [1, 2], "bar": [3, 4], "ham": ["a", "b"]})
+
+    # Single column name
+    result = df.select("foo")
+    expected = pl.DataFrame({"foo": [1, 2]})
+    assert_frame_equal(result, expected)
+
+    # Column names as list
+    result = df.select(["foo", "bar"])
+    expected = pl.DataFrame({"foo": [1, 2], "bar": [3, 4]})
+    assert_frame_equal(result, expected)
+
+    # Column names as positional arguments
+    result = df.select("foo", "bar", "ham")
+    expected = df
+    assert_frame_equal(result, expected)
+
+    # Keyword arguments
+    result = df.select(oof="foo")
+    expected = pl.DataFrame({"oof": [1, 2]})
+    assert_frame_equal(result, expected)
+
+    # Mixed
+    result = df.select(["bar"], "foo", oof="foo")
+    expected = pl.DataFrame({"bar": [3, 4], "foo": [1, 2], "oof": [1, 2]})
+    assert_frame_equal(result, expected)
 
 
 def test_rolling(fruits_cars: pl.DataFrame) -> None:
@@ -707,13 +725,14 @@ def test_rolling(fruits_cars: pl.DataFrame) -> None:
             pl.col("A").rolling_max(3).alias("3b"),
             pl.col("A").rolling_sum(3, min_periods=1).alias("4"),
             pl.col("A").rolling_sum(3).alias("4b"),
-            # below we use .round purely for the ability to do .frame_equal()
+            # below we use .round purely for the ability to do assert frame equality
             pl.col("A").rolling_std(3).round(1).alias("std"),
             pl.col("A").rolling_var(3).round(1).alias("var"),
         ]
     )
 
-    assert out.frame_equal(
+    assert_frame_equal(
+        out,
         pl.DataFrame(
             {
                 "1": [1, 1, 1, 2, 3],
@@ -727,7 +746,7 @@ def test_rolling(fruits_cars: pl.DataFrame) -> None:
                 "std": [None, None, 1.0, 1.0, 1.0],
                 "var": [None, None, 1.0, 1.0, 1.0],
             }
-        )
+        ),
     )
 
     out_single_val_variance = df.select(
@@ -863,7 +882,7 @@ def test_arr_namespace(fruits_cars: pl.DataFrame) -> None:
             ],
         }
     )
-    assert out.frame_equal(expected, null_equal=True)
+    assert_frame_equal(out, expected)
 
 
 def test_arithmetic() -> None:
@@ -899,7 +918,7 @@ def test_arithmetic() -> None:
             "11": [-1, -2, -3],
         }
     )
-    assert out.frame_equal(expected)
+    assert_frame_equal(out, expected)
 
     # floating point floor divide
     x = 10.4
@@ -930,10 +949,44 @@ def test_ufunc() -> None:
             pl.Series("power_uint16", [1, 4, 9, 16], dtype=pl.UInt16),
         ]
     )
-    assert out.frame_equal(expected)
+    assert_frame_equal(out, expected)
     assert out.dtypes == expected.dtypes
 
 
+def test_ufunc_expr_not_first() -> None:
+    """Check numpy ufunc expressions also work if expression not the first argument."""
+    df = pl.DataFrame([pl.Series("a", [1, 2, 3], dtype=pl.Float64)])
+    out = df.select(
+        [
+            np.power(2.0, cast(Any, pl.col("a"))).alias("power"),
+            (2.0 / cast(Any, pl.col("a"))).alias("divide_scalar"),
+            (np.array([2, 2, 2]) / cast(Any, pl.col("a"))).alias("divide_array"),
+        ]
+    )
+    expected = pl.DataFrame(
+        [
+            pl.Series("power", [2**1, 2**2, 2**3], dtype=pl.Float64),
+            pl.Series("divide_scalar", [2 / 1, 2 / 2, 2 / 3], dtype=pl.Float64),
+            pl.Series("divide_array", [2 / 1, 2 / 2, 2 / 3], dtype=pl.Float64),
+        ]
+    )
+    assert_frame_equal(out, expected)
+
+
+def test_ufunc_multiple_expr() -> None:
+    df = pl.DataFrame(
+        [
+            pl.Series("a", [1, 2, 3], dtype=pl.Float64),
+            pl.Series("b", [4, 5, 6], dtype=pl.Float64),
+        ]
+    )
+
+    with pytest.raises(
+        ValueError, match="Numpy ufunc can only be used with one expression, 2 given"
+    ):
+        df.select(np.arctan2(pl.col("a"), pl.col("b")))  # type: ignore[call-overload]
+
+
 def test_clip() -> None:
     df = pl.DataFrame({"a": [1, 2, 3, 4, 5]})
     assert df.select(pl.col("a").clip(2, 4))["a"].to_list() == [2, 2, 3, 4, 4]
@@ -988,14 +1041,6 @@ def test_rename() -> None:
     assert out.columns == ["foo", "bar", "c"]
 
 
-def test_drop_columns() -> None:
-    out = pl.DataFrame({"a": [1], "b": [2], "c": [3]}).lazy().drop(["a", "b"])
-    assert out.columns == ["c"]
-
-    out = pl.DataFrame({"a": [1], "b": [2], "c": [3]}).lazy().drop("a")
-    assert out.columns == ["b", "c"]
-
-
 def test_with_column_renamed(fruits_cars: pl.DataFrame) -> None:
     res = fruits_cars.lazy().rename({"A": "C"}).collect()
     assert res.columns[0] == "C"
@@ -1012,32 +1057,29 @@ def test_with_columns_single_series() -> None:
 def test_reverse() -> None:
     out = pl.DataFrame({"a": [1, 2], "b": [3, 4]}).lazy().reverse()
     expected = pl.DataFrame({"a": [2, 1], "b": [4, 3]})
-    assert out.collect().frame_equal(expected)
+    assert_frame_equal(out.collect(), expected)
 
 
 def test_limit(fruits_cars: pl.DataFrame) -> None:
-    assert fruits_cars.lazy().limit(1).collect().frame_equal(fruits_cars[0, :])
+    assert_frame_equal(fruits_cars.lazy().limit(1).collect(), fruits_cars[0, :])
 
 
 def test_head(fruits_cars: pl.DataFrame) -> None:
-    assert fruits_cars.lazy().head(2).collect().frame_equal(fruits_cars[:2, :])
+    assert_frame_equal(fruits_cars.lazy().head(2).collect(), fruits_cars[:2, :])
 
 
 def test_tail(fruits_cars: pl.DataFrame) -> None:
-    assert fruits_cars.lazy().tail(2).collect().frame_equal(fruits_cars[3:, :])
+    assert_frame_equal(fruits_cars.lazy().tail(2).collect(), fruits_cars[3:, :])
 
 
 def test_last(fruits_cars: pl.DataFrame) -> None:
-    assert (
-        fruits_cars.lazy()
-        .last()
-        .collect()
-        .frame_equal(fruits_cars[(len(fruits_cars) - 1) :, :])
-    )
+    result = fruits_cars.lazy().last().collect()
+    expected = fruits_cars[(len(fruits_cars) - 1) :, :]
+    assert_frame_equal(result, expected)
 
 
 def test_first(fruits_cars: pl.DataFrame) -> None:
-    assert fruits_cars.lazy().first().collect().frame_equal(fruits_cars[0, :])
+    assert_frame_equal(fruits_cars.lazy().first().collect(), fruits_cars[0, :])
 
 
 def test_join_suffix() -> None:
@@ -1061,12 +1103,6 @@ def test_join_suffix() -> None:
     assert out.columns == ["a", "b", "c", "b_bar", "c_bar"]
 
 
-def test_str_concat() -> None:
-    df = pl.DataFrame({"foo": [1, None, 2]})
-    df = df.select(pl.col("foo").str.concat("-"))
-    assert cast(str, df.item()) == "1-null-2"
-
-
 @pytest.mark.parametrize("no_optimization", [False, True])
 def test_collect_all(df: pl.DataFrame, no_optimization: bool) -> None:
     lf1 = df.lazy().select(pl.col("int").sum())
@@ -1177,70 +1213,53 @@ def test_quantile(fruits_cars: pl.DataFrame) -> None:
     assert fruits_cars.select(pl.col("A").quantile(0.24, "linear"))["A"][0] == 1.96
 
 
-@pytest.mark.filterwarnings("ignore::FutureWarning")
 def test_is_between(fruits_cars: pl.DataFrame) -> None:
-    result = fruits_cars.select(pl.col("A").is_between(2, 4))["is_between"]
-    assert result.series_equal(
-        pl.Series("is_between", [False, False, True, False, False])
-    )
+    result = fruits_cars.select(pl.col("A").is_between(2, 4)).to_series()
+    assert_series_equal(result, pl.Series("A", [False, True, True, True, False]))
 
-    result = fruits_cars.select(pl.col("A").is_between(2, 4, closed="none"))[
-        "is_between"
-    ]
-    assert result.series_equal(
-        pl.Series("is_between", [False, False, True, False, False])
-    )
+    result = fruits_cars.select(pl.col("A").is_between(2, 4, closed="none")).to_series()
+    assert_series_equal(result, pl.Series("A", [False, False, True, False, False]))
 
-    result = fruits_cars.select(pl.col("A").is_between(2, 4, closed="both"))[
-        "is_between"
-    ]
-    assert result.series_equal(
-        pl.Series("is_between", [False, True, True, True, False])
-    )
+    result = fruits_cars.select(pl.col("A").is_between(2, 4, closed="both")).to_series()
+    assert_series_equal(result, pl.Series("A", [False, True, True, True, False]))
 
-    result = fruits_cars.select(pl.col("A").is_between(2, 4, closed="right"))[
-        "is_between"
-    ]
-    assert result.series_equal(
-        pl.Series("is_between", [False, False, True, True, False])
-    )
+    result = fruits_cars.select(
+        pl.col("A").is_between(2, 4, closed="right")
+    ).to_series()
+    assert_series_equal(result, pl.Series("A", [False, False, True, True, False]))
 
-    result = fruits_cars.select(pl.col("A").is_between(2, 4, closed="left"))[
-        "is_between"
-    ]
-    assert result.series_equal(
-        pl.Series("is_between", [False, True, True, False, False])
-    )
+    result = fruits_cars.select(pl.col("A").is_between(2, 4, closed="left")).to_series()
+    assert_series_equal(result, pl.Series("A", [False, True, True, False, False]))
 
 
-@pytest.mark.filterwarnings("ignore::FutureWarning")
 def test_is_between_data_types() -> None:
     df = pl.DataFrame(
         {
             "flt": [1.4, 1.2, 2.5],
             "int": [2, 3, 4],
+            "str": ["xyz", "str", "abc"],
             "date": [date(2020, 1, 1), date(2020, 2, 2), date(2020, 3, 3)],
             "datetime": [
                 datetime(2020, 1, 1, 0, 0, 0),
                 datetime(2020, 1, 1, 10, 0, 0),
                 datetime(2020, 1, 1, 12, 0, 0),
             ],
+            "tm": [time(10, 30), time(0, 45), time(15, 15)],
         }
     )
 
     # on purpose, for float and int, we pass in a mixture of bound data types
     assert_series_equal(
         df.select(pl.col("flt").is_between(1, 2.3))[:, 0],
-        pl.Series("is_between", [True, True, False]),
+        pl.Series("flt", [True, True, False]),
     )
     assert_series_equal(
-        df.select(pl.col("int").is_between(1.5, 4))[:, 0],
-        pl.Series("is_between", [True, True, False]),
+        df.select(pl.col("int").is_between(1.5, 3))[:, 0],
+        pl.Series("int", [True, True, False]),
     )
-
     assert_series_equal(
         df.select(pl.col("date").is_between(date(2019, 1, 1), date(2020, 2, 5)))[:, 0],
-        pl.Series("is_between", [True, True, False]),
+        pl.Series("date", [True, True, False]),
     )
     assert_series_equal(
         df.select(
@@ -1248,7 +1267,21 @@ def test_is_between_data_types() -> None:
                 datetime(2020, 1, 1, 5, 0, 0), datetime(2020, 1, 1, 11, 0, 0)
             )
         )[:, 0],
-        pl.Series("is_between", [False, True, False]),
+        pl.Series("datetime", [False, True, False]),
+    )
+    assert_series_equal(
+        df.select(
+            pl.col("str").is_between(pl.lit("str"), pl.lit("zzz"), closed="left")
+        )[:, 0],
+        pl.Series("str", [True, True, False]),
+    )
+    assert_series_equal(
+        df.select(
+            pl.col("tm")
+            .is_between(time(0, 45), time(10, 30), closed="right")
+            .alias("tm_between")
+        )[:, 0],
+        pl.Series("tm_between", [True, False, False]),
     )
 
 
@@ -1256,15 +1289,12 @@ def test_unique() -> None:
     df = pl.DataFrame({"a": [1, 2, 2], "b": [3, 3, 3]})
 
     expected = pl.DataFrame({"a": [1, 2], "b": [3, 3]})
-    assert df.lazy().unique(maintain_order=True).collect().frame_equal(expected)
+    assert_frame_equal(df.lazy().unique(maintain_order=True).collect(), expected)
 
+    result = df.lazy().unique(subset="b", maintain_order=True).collect()
     expected = pl.DataFrame({"a": [1], "b": [3]})
-    assert (
-        df.lazy()
-        .unique(subset="b", maintain_order=True)
-        .collect()
-        .frame_equal(expected)
-    )
+    assert_frame_equal(result, expected)
+
     s0 = pl.Series("a", [1, 2, None, 2])
     # test if the null is included
     assert s0.unique().to_list() == [None, 1, 2]
@@ -1284,46 +1314,46 @@ def test_lazy_concat(df: pl.DataFrame) -> None:
 
     out = pl.concat([df.lazy(), df.lazy()]).collect()
     assert out.shape == shape
-    assert out.frame_equal(df.vstack(df.clone()), null_equal=True)
+    assert_frame_equal(out, df.vstack(df.clone()))
 
 
 def test_max_min_multiple_columns(fruits_cars: pl.DataFrame) -> None:
     res = fruits_cars.select(pl.max(["A", "B"]).alias("max"))
-    assert res.to_series(0).series_equal(pl.Series("max", [5, 4, 3, 4, 5]))
+    assert_series_equal(res.to_series(0), pl.Series("max", [5, 4, 3, 4, 5]))
 
     res = fruits_cars.select(pl.min(["A", "B"]).alias("min"))
-    assert res.to_series(0).series_equal(pl.Series("min", [1, 2, 3, 2, 1]))
+    assert_series_equal(res.to_series(0), pl.Series("min", [1, 2, 3, 2, 1]))
 
 
 def test_max_min_wildcard_columns(fruits_cars: pl.DataFrame) -> None:
     res = fruits_cars.select([pl.col(pl.datatypes.Int64)]).select(pl.min(["*"]))
-    assert res.to_series(0).series_equal(pl.Series("min", [1, 2, 3, 2, 1]))
+    assert_series_equal(res.to_series(0), pl.Series("min", [1, 2, 3, 2, 1]))
     res = fruits_cars.select([pl.col(pl.datatypes.Int64)]).select(pl.min([pl.all()]))
-    assert res.to_series(0).series_equal(pl.Series("min", [1, 2, 3, 2, 1]))
+    assert_series_equal(res.to_series(0), pl.Series("min", [1, 2, 3, 2, 1]))
 
     res = fruits_cars.select([pl.col(pl.datatypes.Int64)]).select(pl.max(["*"]))
-    assert res.to_series(0).series_equal(pl.Series("max", [5, 4, 3, 4, 5]))
+    assert_series_equal(res.to_series(0), pl.Series("max", [5, 4, 3, 4, 5]))
     res = fruits_cars.select([pl.col(pl.datatypes.Int64)]).select(pl.max([pl.all()]))
-    assert res.to_series(0).series_equal(pl.Series("max", [5, 4, 3, 4, 5]))
+    assert_series_equal(res.to_series(0), pl.Series("max", [5, 4, 3, 4, 5]))
 
     res = fruits_cars.select([pl.col(pl.datatypes.Int64)]).select(
         pl.max([pl.all(), "A", "*"])
     )
-    assert res.to_series(0).series_equal(pl.Series("max", [5, 4, 3, 4, 5]))
+    assert_series_equal(res.to_series(0), pl.Series("max", [5, 4, 3, 4, 5]))
 
 
 def test_head_tail(fruits_cars: pl.DataFrame) -> None:
     res_expr = fruits_cars.select([pl.head("A", 2)])
     res_series = pl.head(fruits_cars["A"], 2)
     expected = pl.Series("A", [1, 2])
-    assert res_expr.to_series(0).series_equal(expected)
-    assert res_series.series_equal(expected)
+    assert_series_equal(res_expr.to_series(0), expected)
+    assert_series_equal(res_series, expected)
 
     res_expr = fruits_cars.select([pl.tail("A", 2)])
     res_series = pl.tail(fruits_cars["A"], 2)
     expected = pl.Series("A", [4, 5])
-    assert res_expr.to_series(0).series_equal(expected)
-    assert res_series.series_equal(expected)
+    assert_series_equal(res_expr.to_series(0), expected)
+    assert_series_equal(res_series, expected)
 
 
 def test_lower_bound_upper_bound(fruits_cars: pl.DataFrame) -> None:
@@ -1371,6 +1401,7 @@ def test_self_join() -> None:
 
 def test_preservation_of_subclasses() -> None:
     """Test for LazyFrame inheritance."""
+
     # We should be able to inherit from polars.LazyFrame
     class SubClassedLazyFrame(pl.LazyFrame):
         pass
@@ -1392,26 +1423,23 @@ def test_group_lengths() -> None:
         }
     )
 
-    assert (
-        df.groupby(["group"], maintain_order=True)
-        .agg(
-            [
-                (pl.col("id").unique_counts() / pl.col("id").len())
-                .sum()
-                .alias("unique_counts_sum"),
-                pl.col("id").unique().len().alias("unique_len"),
-            ]
-        )
-        .frame_equal(
-            pl.DataFrame(
-                {
-                    "group": ["A", "B"],
-                    "unique_counts_sum": [1.0, 1.0],
-                    "unique_len": [2, 3],
-                }
-            )
-        )
+    result = df.groupby(["group"], maintain_order=True).agg(
+        [
+            (pl.col("id").unique_counts() / pl.col("id").len())
+            .sum()
+            .alias("unique_counts_sum"),
+            pl.col("id").unique().len().alias("unique_len"),
+        ]
     )
+    expected = pl.DataFrame(
+        {
+            "group": ["A", "B"],
+            "unique_counts_sum": [1.0, 1.0],
+            "unique_len": [2, 3],
+        },
+        schema_overrides={"unique_len": pl.UInt32},
+    )
+    assert_frame_equal(result, expected)
 
 
 def test_quantile_filtered_agg() -> None:
@@ -1491,18 +1519,6 @@ def test_predicate_count_vstack() -> None:
     ].to_list() == [3, 2, 5, 7]
 
 
-def test_explode_inner_lists_3985() -> None:
-    df = pl.DataFrame(
-        data={"id": [1, 1, 1], "categories": [["a"], ["b"], ["a", "c"]]}
-    ).lazy()
-
-    assert (
-        df.groupby("id")
-        .agg(pl.col("categories"))
-        .with_columns(pl.col("categories").arr.eval(pl.element().explode()))
-    ).collect().to_dict(False) == {"id": [1], "categories": [["a", "b", "a", "c"]]}
-
-
 def test_lazy_method() -> None:
     # We want to support `.lazy()` on a Lazy DataFrame as to allow more generic user
     # code.
@@ -1560,13 +1576,15 @@ def test_lazy_cache_same_key() -> None:
     ).collect().to_dict(False) == {"a": [-1, 2, 7], "c": ["x", "y", "z"]}
 
 
-def test_lazy_cache_hit(capfd: Any) -> None:
-    os.environ["POLARS_VERBOSE"] = "1"
+def test_lazy_cache_hit(monkeypatch: Any, capfd: Any) -> None:
+    monkeypatch.setenv("POLARS_VERBOSE", "1")
+
     df = pl.DataFrame({"a": [1, 2, 3], "b": [3, 4, 5], "c": ["x", "y", "z"]}).lazy()
     add_node = df.select([(pl.col("a") + pl.col("b")).alias("a"), pl.col("c")]).cache()
     assert add_node.join(add_node, on="c", suffix="_mult").select(
         [(pl.col("a") - pl.col("a_mult")).alias("a"), pl.col("c")]
     ).collect().to_dict(False) == {"a": [0, 0, 0], "c": ["x", "y", "z"]}
+
     (out, _) = capfd.readouterr()
     assert "CACHE HIT" in out
 
