@@ -8,8 +8,7 @@ import pandas as pd
 import pytest
 
 import polars as pl
-from polars.testing import assert_series_equal
-from polars.testing._private import verify_series_and_expr_api
+from polars.testing import assert_frame_equal, assert_series_equal
 
 
 def test_list_arr_get() -> None:
@@ -58,6 +57,20 @@ def test_list_arr_get() -> None:
     assert df.select([pl.col("cars").arr.get("indexes")]).to_dict(False) == {
         "cars": [2, 3, None, None]
     }
+    # exact on oob boundary
+    df = pl.DataFrame(
+        {
+            "index": [3, 3, 3],
+            "lists": [[3, 4, 5], [4, 5, 6], [7, 8, 9, 4]],
+        }
+    )
+
+    assert df.select(pl.col("lists").arr.get(3)).to_dict(False) == {
+        "lists": [None, None, 4]
+    }
+    assert df.select(pl.col("lists").arr.get(pl.col("index"))).to_dict(False) == {
+        "lists": [None, None, 4]
+    }
 
 
 def test_contains() -> None:
@@ -221,17 +234,18 @@ def test_list_arr_empty() -> None:
         ]
     )
     expected = pl.DataFrame(
-        {"cars_first": [1, 2, 4, None], "cars_literal": [2, 1, 3, 3]}
+        {"cars_first": [1, 2, 4, None], "cars_literal": [2, 1, 3, 3]},
+        schema_overrides={"cars_literal": pl.Int32},  # Literals default to Int32
     )
-    assert out.frame_equal(expected)
+    assert_frame_equal(out, expected)
 
 
 def test_list_argminmax() -> None:
     s = pl.Series("a", [[1, 2], [3, 2, 1]])
     expected = pl.Series("a", [0, 2], dtype=pl.UInt32)
-    verify_series_and_expr_api(s, expected, "arr.arg_min")
+    assert_series_equal(s.arr.arg_min(), expected)
     expected = pl.Series("a", [1, 0], dtype=pl.UInt32)
-    verify_series_and_expr_api(s, expected, "arr.arg_max")
+    assert_series_equal(s.arr.arg_max(), expected)
 
 
 def test_list_shift() -> None:
@@ -427,7 +441,7 @@ def test_arr_contains_categorical() -> None:
         {"str": ["A", "B", "A", "B", "C"], "group": [1, 1, 2, 1, 2]}
     ).lazy()
     df = df.with_columns(pl.col("str").cast(pl.Categorical))
-    df_groups = df.groupby("group").agg([pl.col("str").list().alias("str_list")])
+    df_groups = df.groupby("group").agg([pl.col("str").alias("str_list")])
     assert df_groups.filter(pl.col("str_list").arr.contains("C")).collect().to_dict(
         False
     ) == {"group": [2], "str_list": [["A", "C"]]}
@@ -491,7 +505,7 @@ def test_groupby_list_column() -> None:
         pl.DataFrame({"a": ["a", "b", "a"]})
         .with_columns(pl.col("a").cast(pl.Categorical))
         .groupby("a", maintain_order=True)
-        .agg(pl.col("a").list().alias("a_list"))
+        .agg(pl.col("a").alias("a_list"))
     )
 
     assert df.groupby("a_list", maintain_order=True).first().to_dict(False) == {
@@ -530,21 +544,14 @@ def test_list_sliced_get_5186() -> None:
         }
     )
 
-    assert df.select(
-        [
-            "ind",
-            pl.col("inds").arr.first().alias("first_element"),
-            pl.col("inds").arr.last().alias("last_element"),
-        ]
-    )[10:20].frame_equal(
-        df[10:20].select(
-            [
-                "ind",
-                pl.col("inds").arr.first().alias("first_element"),
-                pl.col("inds").arr.last().alias("last_element"),
-            ]
-        )
-    )
+    exprs = [
+        "ind",
+        pl.col("inds").arr.first().alias("first_element"),
+        pl.col("inds").arr.last().alias("last_element"),
+    ]
+    out1 = df.select(exprs)[10:20]
+    out2 = df[10:20].select(exprs)
+    assert_frame_equal(out1, out2)
 
 
 def test_empty_eval_dtype_5546() -> None:
@@ -565,6 +572,16 @@ def test_fast_explode_flag() -> None:
     df1 = pl.DataFrame({"values": [[[1, 2]]]})
     assert df1.clone().vstack(df1)["values"].flags["FAST_EXPLODE"]
 
+    # test take that produces a null in list
+    df = pl.DataFrame({"a": [1, 2, 1, 3]})
+    df_b = pl.DataFrame({"a": [1, 2], "c": [["1", "2", "c"], ["1", "2", "c"]]})
+    assert df_b["c"].flags["FAST_EXPLODE"]
+
+    # join produces a null
+    assert not (df.join(df_b, on=["a"], how="left").select(["c"]))["c"].flags[
+        "FAST_EXPLODE"
+    ]
+
 
 def test_list_amortized_apply_explode_5812() -> None:
     s = pl.Series([None, [1, 3], [0, -3], [1, 2, 2]])
@@ -629,9 +646,9 @@ def test_fast_explode_on_list_struct_6208() -> None:
             "label": "l",
             "tag": "t",
             "ref": 1,
-            "parent": [{"ref": 1, "tag": "t", "ratio": 62.3}],
+            "parents": [{"ref": 1, "tag": "t", "ratio": 62.3}],
         },
-        {"label": "l", "tag": "t", "ref": 1, "parent": None},
+        {"label": "l", "tag": "t", "ref": 1, "parents": None},
     ]
 
     df = pl.DataFrame(
@@ -656,3 +673,68 @@ def test_fast_explode_on_list_struct_6208() -> None:
             {"ref": None, "tag": None, "ratio": None},
         ],
     }
+
+
+def test_concat_list_in_agg_6397() -> None:
+    df = pl.DataFrame({"group": [1, 2, 2, 3], "value": ["a", "b", "c", "d"]})
+
+    # single list
+    assert df.groupby("group").agg(
+        [
+            # this casts every element to a list
+            pl.concat_list(pl.col("value")),
+        ]
+    ).sort("group").to_dict(False) == {
+        "group": [1, 2, 3],
+        "value": [[["a"]], [["b"], ["c"]], [["d"]]],
+    }
+
+    # nested list
+    assert df.groupby("group").agg(
+        [
+            pl.concat_list(pl.col("value").list()).alias("result"),
+        ]
+    ).sort("group").to_dict(False) == {
+        "group": [1, 2, 3],
+        "result": [[["a"]], [["b", "c"]], [["d"]]],
+    }
+
+
+def test_list_eval_all_null() -> None:
+    df = pl.DataFrame({"foo": [1, 2, 3], "bar": [None, None, None]}).with_columns(
+        pl.col("bar").cast(pl.List(pl.Utf8))
+    )
+
+    assert df.select(pl.col("bar").arr.eval(pl.element())).to_dict(False) == {
+        "bar": [None, None, None]
+    }
+
+
+def test_list_function_group_awareness() -> None:
+    df = pl.DataFrame(
+        {
+            "a": [100, 103, 105, 106, 105, 104, 103, 106, 100, 102],
+            "group": [0, 0, 1, 1, 1, 1, 1, 1, 2, 2],
+        }
+    )
+
+    assert df.groupby("group").agg(
+        [
+            pl.col("a").list().arr.get(0).alias("get"),
+            pl.col("a").list().arr.take([0]).alias("take"),
+            pl.col("a").list().arr.slice(0, 3).alias("slice"),
+        ]
+    ).sort("group").to_dict(False) == {
+        "group": [0, 1, 2],
+        "get": [[100], [105], [100]],
+        "take": [[[100]], [[105]], [[100]]],
+        "slice": [[[100, 103]], [[105, 106, 105]], [[100, 102]]],
+    }
+
+
+def test_flat_aggregation_to_list_conversion_6918() -> None:
+    df = pl.DataFrame({"a": [1, 2, 2], "b": [[0, 1], [2, 3], [4, 5]]})
+
+    assert df.groupby("a", maintain_order=True).agg(
+        pl.concat_list([pl.col("b").arr.get(i).mean().list() for i in range(2)])
+    ).to_dict(False) == {"a": [1, 2], "b": [[[0.0, 1.0]], [[3.0, 4.0]]]}
