@@ -964,18 +964,6 @@ def test_repeat() -> None:
     assert s.len() == 5
 
 
-def test_median() -> None:
-    s = pl.Series([1, 2, 3])
-    assert s.median() == 2
-
-
-def test_quantile() -> None:
-    s = pl.Series([1, 2, 3])
-    assert s.quantile(0.5, "nearest") == 2
-    assert s.quantile(0.5, "lower") == 2
-    assert s.quantile(0.5, "higher") == 2
-
-
 def test_shape() -> None:
     s = pl.Series([1, 2, 3])
     assert s.shape == (3,)
@@ -1634,14 +1622,14 @@ def test_take_every() -> None:
     assert_series_equal(s.take_every(2), pl.Series("a", [1, 3]))
 
 
-def test_argsort() -> None:
+def test_arg_sort() -> None:
     s = pl.Series("a", [5, 3, 4, 1, 2])
     expected = pl.Series("a", [3, 4, 1, 2, 0], dtype=UInt32)
 
-    assert_series_equal(s.argsort(), expected)
+    assert_series_equal(s.arg_sort(), expected)
 
     expected_reverse = pl.Series("a", [0, 2, 1, 4, 3], dtype=UInt32)
-    assert_series_equal(s.argsort(True), expected_reverse)
+    assert_series_equal(s.arg_sort(reverse=True), expected_reverse)
 
 
 def test_arg_min_and_arg_max() -> None:
@@ -1665,6 +1653,18 @@ def test_arg_min_and_arg_max() -> None:
     assert s.arg_min() == 0
     assert s.arg_max() == 1
 
+    # test ascending and descending series
+    s = pl.Series("a", [1, 2, 3, 4, 5])
+    s.sort(in_place=True)  # set ascending sorted flag
+    assert s.flags == {"SORTED_ASC": True, "SORTED_DESC": False}
+    assert s.arg_min() == 0
+    assert s.arg_max() == 4
+    s = pl.Series("a", [5, 4, 3, 2, 1])
+    s.sort(reverse=True, in_place=True)  # set descing sorted flag
+    assert s.flags == {"SORTED_ASC": False, "SORTED_DESC": True}
+    assert s.arg_min() == 4
+    assert s.arg_max() == 0
+
 
 def test_is_null_is_not_null() -> None:
     s = pl.Series("a", [1.0, 2.0, 3.0, None])
@@ -2351,3 +2351,44 @@ def test_min_max_agg_on_str() -> None:
     strings = ["b", "a", "x"]
     s = pl.Series(strings)
     assert (s.min(), s.max()) == ("a", "x")
+
+
+def test_is_between() -> None:
+    s = pl.Series("num", [1, 2, None, 4, 5])
+    assert s.is_between(2, 4).to_list() == [False, True, None, True, False]
+
+    s = pl.Series("num", [1, 2, None, 4, 5])
+    assert s.is_between(2, 4, closed="left").to_list() == [
+        False,
+        True,
+        None,
+        False,
+        False,
+    ]
+
+    s = pl.Series("num", [1, 2, None, 4, 5])
+    assert s.is_between(2, 4, closed="right").to_list() == [
+        False,
+        False,
+        None,
+        True,
+        False,
+    ]
+
+    s = pl.Series("num", [1, 2, None, 4, 5])
+    assert s.is_between(pl.lit(2) / 2, pl.lit(4) * 2, closed="both").to_list() == [
+        True,
+        True,
+        None,
+        True,
+        True,
+    ]
+
+    s = pl.Series("s", ["a", "b", "c", "d", "e"])
+    assert s.is_between("b", "d").to_list() == [
+        False,
+        True,
+        True,
+        True,
+        False,
+    ]
