@@ -3,6 +3,7 @@ from __future__ import annotations
 from datetime import datetime
 
 import polars as pl
+from polars.testing import assert_frame_equal
 
 
 def test_sort_dates_multiples() -> None:
@@ -65,10 +66,10 @@ def test_sort_by_exprs() -> None:
     assert out.to_list() == [1, -1, 2, -2]
 
 
-def test_argsort_nulls() -> None:
+def test_arg_sort_nulls() -> None:
     a = pl.Series("a", [1.0, 2.0, 3.0, None, None])
-    assert a.argsort(nulls_last=True).to_list() == [0, 1, 2, 4, 3]
-    assert a.argsort(nulls_last=False).to_list() == [3, 4, 0, 1, 2]
+    assert a.arg_sort(nulls_last=True).to_list() == [0, 1, 2, 4, 3]
+    assert a.arg_sort(nulls_last=False).to_list() == [3, 4, 0, 1, 2]
 
     assert a.to_frame().sort(by="a", nulls_last=False).to_series().to_list() == [
         None,
@@ -86,17 +87,17 @@ def test_argsort_nulls() -> None:
     ]
 
 
-def test_argsort_window_functions() -> None:
+def test_arg_sort_window_functions() -> None:
     df = pl.DataFrame({"Id": [1, 1, 2, 2, 3, 3], "Age": [1, 2, 3, 4, 5, 6]})
     out = df.select(
         [
             pl.col("Age").arg_sort().over("Id").alias("arg_sort"),
-            pl.argsort_by("Age").over("Id").alias("argsort_by"),
+            pl.arg_sort_by("Age").over("Id").alias("arg_sort_by"),
         ]
     )
 
     assert (
-        out["arg_sort"].to_list() == out["argsort_by"].to_list() == [0, 1, 0, 1, 0, 1]
+        out["arg_sort"].to_list() == out["arg_sort_by"].to_list() == [0, 1, 0, 1, 0, 1]
     )
 
 
@@ -168,7 +169,7 @@ def test_sort_aggregation_fast_paths() -> None:
                     .suffix("_min"),
                 ]
             )
-            assert out.frame_equal(expected)
+            assert_frame_equal(out, expected)
 
 
 def test_sorted_join_and_dtypes() -> None:
@@ -213,7 +214,7 @@ def test_sorted_fast_paths() -> None:
     assert rev.sort().to_list() == [None, 1, 2, 3]
 
 
-def test_argsort_rank_nans() -> None:
+def test_arg_sort_rank_nans() -> None:
     assert (
         pl.DataFrame(
             {
@@ -223,11 +224,11 @@ def test_argsort_rank_nans() -> None:
         .with_columns(
             [
                 pl.col("val").rank().alias("rank"),
-                pl.col("val").argsort().alias("argsort"),
+                pl.col("val").arg_sort().alias("arg_sort"),
             ]
         )
-        .select(["rank", "argsort"])
-    ).to_dict(False) == {"rank": [1.0, 2.0], "argsort": [0, 1]}
+        .select(["rank", "arg_sort"])
+    ).to_dict(False) == {"rank": [1.0, 2.0], "arg_sort": [0, 1]}
 
 
 def test_top_k() -> None:
@@ -238,7 +239,7 @@ def test_top_k() -> None:
 
     # 5886
     df = pl.DataFrame({"test": [4, 3, 2, 1]})
-    assert df.select(pl.col("test").top_k(10)).frame_equal(df)
+    assert_frame_equal(df.select(pl.col("test").top_k(10)), df)
 
 
 def test_sorted_flag_unset_by_arithmetic_4937() -> None:
@@ -294,13 +295,11 @@ def test_sort_slice_fast_path_5245() -> None:
 
 def test_explicit_list_agg_sort_in_groupby() -> None:
     df = pl.DataFrame({"A": ["a", "a", "a", "b", "b", "a"], "B": [1, 2, 3, 4, 5, 6]})
-    assert (
-        df.groupby("A")
-        # this was col().list().sort() before we changed the logic
-        .agg(pl.col("B").sort(reverse=True))
-        .sort("A")
-        .frame_equal(df.groupby("A").agg(pl.col("B").sort(reverse=True)).sort("A"))
-    )
+
+    # this was col().list().sort() before we changed the logic
+    result = df.groupby("A").agg(pl.col("B").sort(reverse=True)).sort("A")
+    expected = df.groupby("A").agg(pl.col("B").sort(reverse=True)).sort("A")
+    assert_frame_equal(result, expected)
 
 
 def test_sorted_join_query_5406() -> None:
@@ -357,7 +356,6 @@ def test_sort_by_in_over_5499() -> None:
 
 
 def test_merge_sorted() -> None:
-
     df_a = (
         pl.date_range(datetime(2022, 1, 1), datetime(2022, 12, 1), "1mo")
         .to_frame("range")
