@@ -797,4 +797,26 @@ def test_struct_null_cast() -> None:
         .lazy()
         .select([pl.lit(None, dtype=pl.Null).cast(dtype, strict=True)])
         .collect()
-    ).to_dict(False) == {"": [{"a": None, "b": None, "c": None}]}
+    ).to_dict(False) == {"literal": [{"a": None, "b": None, "c": None}]}
+
+
+def test_nested_struct_in_lists_cast() -> None:
+    assert pl.DataFrame(
+        {
+            "node_groups": [
+                [{"nodes": [{"id": 1, "is_started": True}]}],
+                [{"nodes": []}],
+            ]
+        }
+    ).to_dict(False) == {
+        "node_groups": [[{"nodes": [{"id": 1, "is_started": True}]}], [{"nodes": []}]]
+    }
+
+
+def test_is_unique_struct() -> None:
+    assert pl.Series(
+        [{"a": 1, "b": 1}, {"a": 2, "b": 1}, {"a": 1, "b": 1}]
+    ).is_unique().to_list() == [False, True, False]
+    assert pl.Series(
+        [{"a": 1, "b": 1}, {"a": 2, "b": 1}, {"a": 1, "b": 1}]
+    ).is_duplicated().to_list() == [True, False, True]
